Scriptname RDO_MCMConfig extends ski_configbase  Conditional
{renn's Tweak 1.1}
; Script used for Relationship Dialogue Overhaul (RDO) Mod Configuration Menu (MCM)

; This extends ski_configbase "Conditional" so variables can be used in condition checks (GetVMQuestVariable)


; Author ------------ cloudedtruth aka Swissenergy
;
; Date Created ------ Winter 2015 - Summer 2016
;
; Purpose ----------- Allows users to change various option about RDO that alters the dialogue that can be used by NPCs.
;
; Versions:
;
; v1.0 -------------- Initial Release
; v1.1 -------------- Added new option to allow for non-married NPCs to address the player as lover if the user wants to have them do so.
;      -------------- Added a GlobalVariable variable for the rival merchant services, which injects into Update.esm. This allows other mods to access the variable without needing RDO as a required master.  


; Other Notes:
; If comments or script contents ever refer to "add" or "adding" an actor, this means the same as "prevent" or "preventing" an actor.
; If comments or script contents ever refer to "remove" or "removing" an actor, this means the same as "allow" or "allowing" an actor.
; Also, I am NOT a Papyrus expert by any means. Scripting is still something that I'm learning and understanding.
; So, what you see written here may not be the best or most efficient methods for scripting.

; This was written using Notepad++ so the indentations may not look correct if viewed in another application.


;################################################;
;
; Credit
;
;################################################;

; Massive thank you to the following:
; FoxFingers - Whose Amorous Adventures (AA) mod was the influence behind me making RDO, and learning from a few of his scripts.
; Expired - Whose Extensible Follower Framework (EFF) scripts provided examples for me to learn. Especially showing me how use the crosshair actor feature in SKSE.
; CPU - Whose papyrus guide on LL gave me some helpful information.
; Schlangster + SkyUI Team - For providing the means/source code for this to happen, and Schlangster's MCM guide.
; DrHappy - Whose Souls Quick Menu scripts helped me with the kinds arrays I needed.
; CreationKit Wiki - Helped me understand a few scripting concepts especially with having the user submitted example scripts which were the most helpful, and...
;;;; for showing me how to compile scripts through Notepad++.
; Myself - ... No, seriously. Trial and error, trial and error, trial and error. I'm not boasting, I'm simply saying that learning involves trying and understanding your mistakes.
;;;; I'm a novice with Papyrus. There are others who can make me look like a child with scripting. But, the only way you'll ever be able to accomplish anything (scripting in this case) is to just try.
;;;; By not trying you've already failed... so what do you have to lose?
;
; Music that helped me get through this very slow, tedious, and tiring process
; Don't know why I put this in here... I just kind of felt like it, I guess...
; Metallica + San Francisco Symphony Orchestra (S&M)
; Breaking Benjamin
; The Stranded
; Thousand Foot Krutch
; Jeremy Soule
; Andrew W.K.
; E.S. Posthumus
; Les Friction
; Two Steps From Hell
; Skillet


;################################################;
;
; Imports
;
;################################################;

Import Game
Import Utility


;################################################;
;
; Actors & Reference Aliases
;
;################################################;

Actor Property PlayerRef Auto								; The best way to refer to the player. The Game.GetPlayer() method is much slower and requires more processing than using PlayerRef


;################################################;
;
; Factions
;
;################################################;

Faction Property PotentialFollowerFaction Auto				; Used for forcing an actor to become a potential follower
Faction Property PotentialMarriageFaction Auto				; Used for forcing an actor to become a potential spouse
Faction Property MarriageExcludedFaction Auto				; Prevents the user from forcing certain actors to be potential spouses, which includes: all Jarls (both Imperial and Stormcloak), Ulfric, Tullius, Galmar, Rikke, and Meridia


;################################################;
;
; Form Lists
;
;################################################;

FormList Property aaa_RDOVoicesFollowerAll Auto				; The list of voice types that RDO supports for being a follower
FormList Property aaa_RDOVoicesMarriageAll Auto				; The list of voice types that RDO supports for being a spouse
FormList Property VoicesFollowerAll Auto					; Default voice types that support follower dialogue, used to compare with RDO list in case another mod adds voice types to this list
FormList Property VoicesMarriageAll Auto					; Default voice types that support marriage dialogue, used to compare with RDO list in case another mod adds voice types to this list
FormList Property aaa_RDOVoicesAll Auto						; All voice types covered by RDO (Unique and Non-Unique)
FormList Property aaa_RDOPreventedActorsList Auto			; List of all the prevented actors by the user


;################################################;
;
; Declare Arrays, index counters, and non-state OIDs
;
;################################################;

String[] ActorsPrevented									; The array that will hold the actors prevented from RDO dialogue by the user
int[] ActorsListIndex										; The array that will keep track of the index each prevented actor is at
int NextActorIndex = 0										; The next index a prevented actor can be added at

int IdleDialogueInfo
int ExtraGuardDialogue
int MoreSpouseDialogue
int HSCRLTradeLine
int FriendlyDialogueInfo
int EnemyDialogueInfo
int SilentBlocker
int NoVendorServices
int SetActorMorality
int SetActorAssistance

; v1.1
int NonSpouseLoverDialogue
GlobalVariable Property a_RDOBlockRivalServices Auto


;################################################;
;
; Declare Toggle states
;
;################################################;
;
;
;################################################;
;
;---Master Control Toggles
;
;################################################;
; Allow the user to toggle on or off the master control options in MCM
; Variables are "Conditional" so they can be used in condition checks

; Toggles For Friendlies
bool property FemaleArgonianFriendVal = True Auto Conditional;
bool property FemaleChildFriendVal = True Auto Conditional;
bool property FemaleCommanderFriendVal = True Auto Conditional;
bool property FemaleCommonerFriendVal = True Auto Conditional;
bool property FemaleCondescendingFriendVal = True Auto Conditional;
bool property FemaleCowardFriendVal = True Auto Conditional;
bool property FemaleDarkElfFriendVal = True Auto Conditional;
bool property FemaleDarkElfCommonerFriendVal = True Auto Conditional;
bool property FemaleElfHaughtyFriendVal = True Auto Conditional;
bool property FemaleEvenTonedFriendVal = True Auto Conditional;
bool property FemaleKhajiitFriendVal = True Auto Conditional;
bool property FemaleNordFriendVal = True Auto Conditional;
bool property FemaleOldGrumpyFriendVal = True Auto Conditional;
bool property FemaleOldKindlyFriendVal = True Auto Conditional;
bool property FemaleOrcFriendVal = True Auto Conditional;
bool property FemaleShrillFriendVal = True Auto Conditional;
bool property FemaleSultryFriendVal = True Auto Conditional;
bool property FemaleYoungEagerFriendVal = True Auto Conditional;
bool property FemaleUniqueFreaFriendVal = True Auto Conditional;
bool property FemaleUniqueSeranaFriendVal = True Auto Conditional;
bool property FemaleUniqueValericaFriendVal = True Auto Conditional;
bool property MaleArgonianFriendVal = True Auto Conditional;
bool property MaleBanditFriendVal = True Auto Conditional;
bool property MaleBruteFriendVal = True Auto Conditional;
bool property MaleChildFriendVal = True Auto Conditional;
bool property MaleCommanderFriendVal = True Auto Conditional;
bool property MaleCommonerFriendVal = True Auto Conditional;
bool property MaleCommonerAccentedFriendVal = True Auto Conditional;
bool property MaleCondescendingFriendVal = True Auto Conditional;
bool property MaleCowardFriendVal = True Auto Conditional;
bool property MaleDarkElfFriendVal = True Auto Conditional;
bool property MaleDarkElfCommonerFriendVal = True Auto Conditional;
bool property MaleDarkElfCynicalFriendVal = True Auto Conditional;
bool property MaleDrunkFriendVal = True Auto Conditional;
bool property MaleElfHaughtyFriendVal = True Auto Conditional;
bool property MaleEvenTonedFriendVal = True Auto Conditional;
bool property MaleEvenTonedAccentedFriendVal = True Auto Conditional;
bool property MaleForswornFriendVal = True Auto Conditional;
bool property MaleGuardFriendVal = True Auto Conditional;
bool property MaleKhajiitFriendVal = True Auto Conditional;
bool property MaleNordFriendVal = True Auto Conditional;
bool property MaleNordCommanderFriendVal = True Auto Conditional;
bool property MaleOldGrumpyFriendVal = True Auto Conditional;
bool property MaleOldKindlyFriendVal = True Auto Conditional;
bool property MaleOrcFriendVal = True Auto Conditional;
bool property MaleSlyCynicalFriendVal = True Auto Conditional;
bool property MaleSoldierFriendVal = True Auto Conditional;
bool property MaleYoungEagerFriendVal = True Auto Conditional;

bool property ExtraGuardDialogueVal = True Auto Conditional;
bool property HSCRLTradeLineVal = False Auto Conditional;
bool property UseSpouseDialogueVal = True Auto Conditional;

; v1.1
bool property NonSpouseLoverDialogueVal = False Auto Conditional;


; Toggles For Enemies


bool property FemaleArgonianEnemyVal = True Auto Conditional;
bool property FemaleChildEnemyVal = True Auto Conditional;
bool property FemaleCommanderEnemyVal = True Auto Conditional;
bool property FemaleCommonerEnemyVal = True Auto Conditional;
bool property FemaleCondescendingEnemyVal = True Auto Conditional;
bool property FemaleCowardEnemyVal = True Auto Conditional;
bool property FemaleDarkElfEnemyVal = True Auto Conditional;
bool property FemaleDarkElfCommonerEnemyVal = True Auto Conditional;
bool property FemaleElfHaughtyEnemyVal = True Auto Conditional;
bool property FemaleEvenTonedEnemyVal = True Auto Conditional;
bool property FemaleKhajiitEnemyVal = True Auto Conditional;
bool property FemaleNordEnemyVal = True Auto Conditional;
bool property FemaleOldGrumpyEnemyVal = True Auto Conditional;
bool property FemaleOldKindlyEnemyVal = True Auto Conditional;
bool property FemaleOrcEnemyVal = True Auto Conditional;
bool property FemaleShrillEnemyVal = True Auto Conditional;
bool property FemaleSultryEnemyVal = True Auto Conditional;
bool property FemaleYoungEagerEnemyVal = True Auto Conditional;
bool property MaleArgonianEnemyVal = True Auto Conditional;
bool property MaleBanditEnemyVal = True Auto Conditional;
bool property MaleBruteEnemyVal = True Auto Conditional;
bool property MaleChildEnemyVal = True Auto Conditional;
bool property MaleCommanderEnemyVal = True Auto Conditional;
bool property MaleCommonerEnemyVal = True Auto Conditional;
bool property MaleCommonerAccentedEnemyVal = True Auto Conditional;
bool property MaleCondescendingEnemyVal = True Auto Conditional;
bool property MaleCowardEnemyVal = True Auto Conditional;
bool property MaleDarkElfEnemyVal = True Auto Conditional;
bool property MaleDarkElfCommonerEnemyVal = True Auto Conditional;
bool property MaleDarkElfCynicalEnemyVal = True Auto Conditional;
bool property MaleDrunkEnemyVal = True Auto Conditional;
bool property MaleElfHaughtyEnemyVal = True Auto Conditional;
bool property MaleEvenTonedEnemyVal = True Auto Conditional;
bool property MaleEvenTonedAccentedEnemyVal = True Auto Conditional;
bool property MaleForswornEnemyVal = True Auto Conditional;
bool property MaleGuardEnemyVal = True Auto Conditional;
bool property MaleKhajiitEnemyVal = True Auto Conditional;
bool property MaleNordEnemyVal = True Auto Conditional;
bool property MaleNordCommanderEnemyVal = True Auto Conditional;
bool property MaleOldGrumpyEnemyVal = True Auto Conditional;
bool property MaleOldKindlyEnemyVal = True Auto Conditional;
bool property MaleOrcEnemyVal = True Auto Conditional;
bool property MaleSlyCynicalEnemyVal = True Auto Conditional;
bool property MaleSoldierEnemyVal = True Auto Conditional;
bool property MaleYoungEagerEnemyVal = True Auto Conditional;

bool property EnemySilentBlockerVal = True Auto Conditional;
bool property EnemyBlockServicesVal = True Auto Conditional;


;################################################;
;
;---Follower Idle Dialogue Toggles
;
;################################################;
; Allows user to toggle on or off the idle dialogue options in MCM
; Variables are "Conditional" so they can be used in condition checks

;bool property FemaleArgonianIdleVal = True Auto Conditional;
;bool property FemaleChildIdleVal = True Auto Conditional;
bool property FemaleCommanderIdleVal = True Auto Conditional;
;bool property FemaleCommonerIdleVal = True Auto Conditional;
bool property FemaleCondescendingIdleVal = True Auto Conditional;
;bool property FemaleCowardIdleVal = True Auto Conditional;
bool property FemaleDarkElfIdleVal = True Auto Conditional;
;bool property FemaleDarkElfCommonerIdleVal = True Auto Conditional;
bool property FemaleElfHaughtyIdleVal = True Auto Conditional;
bool property FemaleEvenTonedIdleVal = True Auto Conditional;
;bool property FemaleKhajiitIdleVal = True Auto Conditional;
bool property FemaleNordIdleVal = True Auto Conditional;
;bool property FemaleOldGrumpyIdleVal = True Auto Conditional;
;bool property FemaleOldKindlyIdleVal = True Auto Conditional;
bool property FemaleOrcIdleVal = True Auto Conditional;
;bool property FemaleShrillIdleVal = True Auto Conditional;
bool property FemaleSultryIdleVal = True Auto Conditional;
bool property FemaleYoungEagerIdleVal = True Auto Conditional;
bool property FemaleUniqueSeranaIdleVal = True Auto Conditional;
bool property FemaleUniqueFreaIdleVal = True Auto Conditional;
bool property MaleArgonianIdleVal = True Auto Conditional;
;bool property MaleBanditIdleVal = True Auto Conditional;
bool property MaleBruteIdleVal = True Auto Conditional;
;bool property MaleChildIdleVal = True Auto Conditional;
;bool property MaleCommanderIdleVal = True Auto Conditional;
;bool property MaleCommonerIdleVal = True Auto Conditional;
;bool property MaleCommonerAccentedIdleVal = True Auto Conditional;
;bool property MaleCondescendingIdleVal = True Auto Conditional;
;bool property MaleCowardIdleVal = True Auto Conditional;
bool property MaleDarkElfIdleVal = True Auto Conditional;
;bool property MaleDarkElfCommonerIdleVal = True Auto Conditional;
bool property MaleDarkElfCynicalIdleVal = True Auto Conditional;
bool property MaleDrunkIdleVal = True Auto Conditional;
;bool property MaleElfHaughtyIdleVal = True Auto Conditional;
bool property MaleEvenTonedIdleVal = True Auto Conditional;
bool property MaleEvenTonedAccentedIdleVal = True Auto Conditional;
;bool property MaleForswornIdleVal = True Auto Conditional;
;bool property MaleGuardIdleVal = True Auto Conditional;
bool property MaleKhajiitIdleVal = True Auto Conditional;
bool property MaleNordIdleVal = True Auto Conditional;
;bool property MaleNordCommanderIdleVal = True Auto Conditional;
;bool property MaleOldGrumpyIdleVal = True Auto Conditional;
;bool property MaleOldKindlyIdleVal = True Auto Conditional;
bool property MaleOrcIdleVal = True Auto Conditional;
;bool property MaleSlyCynicalIdleVal = True Auto Conditional;
;bool property MaleSoldierIdleVal = True Auto Conditional;
bool property MaleYoungEagerIdleVal = True Auto Conditional;


;################################################;
;
; All Functions
;
;################################################;
; The functions below are called for certain MCM options

; For those new to scripting or do not know:
; The two ampersand symbols together, && , is the AND operator
; The two straight lines together, || , is the OR operator


; Is the Generic Actor valid to have their relationship rank with the player changed
bool Function RDO_IsGenericActorValid(Actor CurrentActor)

	; Check to make sure the current actor being checked is not nothing
	If CurrentActor == None
		Return False
	EndIf
	
	; Check to see if the current actor has a voice type that is supported by RDO
	If aaa_RDOVoicesAll.HasForm(CurrentActor.GetVoiceType())
		Return True
	EndIf
	
	; Failsafe
	; Return false if all else fails just to avoid possible problems
	Return False
	
EndFunction

; Is the Actor valid
bool Function RDO_IsActorValid(Actor CurrentActor)

	; Check to make sure the current actor being checked is not nothing
	If CurrentActor == None
		Return False
	EndIf
	
	; Check to see if the current actor has a voice type that is supported by RDO, and if the actor is unique
	If aaa_RDOVoicesAll.HasForm(CurrentActor.GetVoiceType()) && CurrentActor.GetLeveledActorBase().IsUnique()
		Return True
	EndIf
	
	; Failsafe
	; Return false if all else fails just to avoid possible problems
	Return False
EndFunction


; Is the Actor a valid potential follower
bool Function RDO_IsActorValidFollower(Actor CurrentActor)
	
	; Check to make sure the current actor being checked is not nothing
	If CurrentActor == None
		Return False
	EndIf
	
	; Since we're checking to make the actor a follower, check to see if the actor is already a potential follower
	If CurrentActor.IsInFaction(PotentialFollowerFaction)
		Return False
	EndIf
	
	; Check RDO's follower voices list and the original list from Skyrim.esm in case another mod adds different voice types to that list
	; Then check to make sure the actor is unique, so the user can't recruit and make a non-persistent reference become persistent
	
	If (aaa_RDOVoicesFollowerAll.HasForm(CurrentActor.GetVoiceType()) || VoicesFollowerAll.HasForm(CurrentActor.GetVoiceType())) && CurrentActor.GetLeveledActorBase().IsUnique()
		Return True
	EndIf
	
	; Failsafe
	; Return false if all else fails just to avoid possible problems
	Return False
EndFunction


; Is the Actor a valid potential spouse
bool Function RDO_IsActorValidSpouse(Actor CurrentActor)

	; Check to make sure the current actor being checked is not nothing
	If CurrentActor == None
		Return False
	EndIf
	
	; Since we're checking to make the actor a potential spouse, check to see if the actor is already a potential spouse
	If CurrentActor.IsInFaction(PotentialMarriageFaction)
		Return False
	EndIf
	
	; Check RDO's spouse voices list and the original list from Skyrim.esm in case another mod adds different voice types to that list
	; Then check to make sure the actor is unique, to not persist non-persistent references, and ensure the actor is not in the marriage excluded faction
	
	If (aaa_RDOVoicesMarriageAll.HasForm(CurrentActor.GetVoiceType()) || VoicesMarriageAll.HasForm(CurrentActor.GetVoiceType())) && CurrentActor.GetLeveledActorBase().IsUnique() && !CurrentActor.IsInFaction(MarriageExcludedFaction)
		Return True
	EndIf
	
	; Failsafe
	; Return false if all else fails just to avoid possible problems
	Return False
EndFunction


; Show Disposition Rank of the Actor
String Function RDO_ShowDisposition(Actor CurrentActor)
	String CurrentRank = CurrentActor.GetRelationshipRank(PlayerRef)
	If CurrentRank == "0"
		CurrentRank = "$RDODispositionAcquaintanceRank"
	ElseIf CurrentRank == "1"
		CurrentRank = "$RDODispositionFriendRank"
	ElseIf CurrentRank == "2"
		CurrentRank = "$RDODispositionConfidentRank"
	ElseIf CurrentRank == "3"
		CurrentRank = "$RDODispositionAllyRank"
	ElseIf CurrentRank == "4"
		CurrentRank = "$RDODispositionLoverRank"
	ElseIf CurrentRank == "-1"
		CurrentRank = "$RDODispositionRivalRank"
	ElseIf CurrentRank == "-2"
		CurrentRank = "$RDODispositionFoeRank"
	ElseIf CurrentRank == "-3"
		CurrentRank = "$RDODispositionEnemyRank"
	ElseIf CurrentRank == "-4"
		CurrentRank = "$RDODispositionArchnemesisRank"
	EndIf
	Return CurrentRank
EndFunction


; Set the Disposition rank of the Actor
; There are two disposition values not used: (-3) and (-4)
; This is because these ranks can cause the Actor to become hostile towards the player, depending on faction combat reactions and the aggression of that actor

String Function RDO_SetActorDisposition(Actor CurrentActor)
	String SetRankTo = CurrentActor.GetRelationshipRank(PlayerRef)
	If SetRankTo == "0"
		CurrentActor.SetRelationShipRank((PlayerRef), 1)
		SetRankTo = "$RDODispositionFriendRank"
	ElseIf SetRankTo == "1"
		CurrentActor.SetRelationShipRank((PlayerRef), 2)
		SetRankTo = "$RDODispositionConfidentRank"
	ElseIf SetRankTo == "2"
		CurrentActor.SetRelationShipRank((PlayerRef), 3)
		SetRankTo = "$RDODispositionAllyRank"
	ElseIf SetRankTo == "3"
		CurrentActor.SetRelationShipRank((PlayerRef), 4)
		SetRankTo = "$RDODispositionLoverRank"
	ElseIf SetRankTo == "4"
		CurrentActor.SetRelationShipRank((PlayerRef), -2)
		SetRankTo = "$RDODispositionFoeRank"
	ElseIf SetRankTo == "-2"
		CurrentActor.SetRelationShipRank((PlayerRef), -1)
		SetRankTo = "$RDODispositionRivalRank"
	ElseIf SetRankTo == "-1"
		CurrentActor.SetRelationShipRank((PlayerRef), 0)
		SetRankTo = "$RDODispositionAcquaintanceRank"
	EndIf
	Return SetRankTo
EndFunction


; Get the aggression of the Actor
String Function RDO_GetActorAggression(Actor CurrentActor)
	; Get the value as an "int" instead of a "float" for simpler comparisons
	String CurrentRank = CurrentActor.GetActorValue("Aggression") as int ;SE
	If CurrentRank == "0"
		CurrentRank = "$RDOAggressionUnaggressive"
	ElseIf CurrentRank == "1"
		CurrentRank = "$RDOAggressionAggressive"
	ElseIf CurrentRank == "2"
		CurrentRank = "$RDOAggressionVeryAggressive"
	ElseIf CurrentRank == "3"
		CurrentRank = "$RDOAggressionFrenzied"
	EndIf
	Return CurrentRank
EndFunction


; Set the aggression of the Actor
; Do not use any values higher than 1.0 (Aggressive) to avoid the actor from attacking anyone other than enemies
; As NPCs with the aggression value of 2.0 (Very Aggressive) will cause them to attack neutral NPCs on sight
; And NPCs with a 3.0 (Frenzied) value, will attack any actor they see (friends, allies, enemies, or neutrals)

String Function RDO_SetActorAggression(Actor CurrentActor)
	; Get the value as an "int" instead of a "float" for simpler comparisons
	String CurrentRank = CurrentActor.GetActorValue("Aggression") as int
	If CurrentRank == "0"
		CurrentActor.SetActorValue("Aggression", 1.0)
		CurrentRank = "$RDOAggressionAggressive"
	ElseIf ((CurrentRank == "1") || (CurrentRank == "2") || (CurrentRank == "3"))
		CurrentActor.SetActorValue("Aggression", 0.0)
		CurrentRank = "$RDOAggressionUnaggressive"
	EndIf
	Return CurrentRank
EndFunction


; Get the confidence of the Actor
String Function RDO_GetActorConfidence(Actor CurrentActor)
	; Get the value as an "int" instead of a "float" for simpler comparisons
	String CurrentRank = CurrentActor.GetActorValue("Confidence") as int
	If CurrentRank == "0"
		CurrentRank = "$RDOConfidenceCowardly"
	ElseIf CurrentRank == "1"
		CurrentRank = "$RDOConfidenceCautious"
	ElseIf CurrentRank == "2"
		CurrentRank = "$RDOConfidenceAverage"
	ElseIf CurrentRank == "3"
		CurrentRank = "$RDOConfidenceBrave"
	ElseIf CurrentRank == "4"
		CurrentRank = "$RDOConfidenceFoolhardy"
	EndIf
	Return CurrentRank
EndFunction


; Set the confidence of the Actor
String Function RDO_SetActorConfidence(Actor CurrentActor)
	; Get the value as an "int" instead of a "float" for simpler comparisons
	String CurrentRank = CurrentActor.GetActorValue("Confidence") as int
	If CurrentRank == "0"
		CurrentActor.SetActorValue("Confidence", 1.0)
		CurrentRank = "$RDOConfidenceCautious"
	ElseIf CurrentRank == "1"
		CurrentActor.SetActorValue("Confidence", 2.0)
		CurrentRank = "$RDOConfidenceAverage"
	ElseIf CurrentRank == "2"
		CurrentActor.SetActorValue("Confidence", 3.0)
		CurrentRank = "$RDOConfidenceBrave"
	ElseIf CurrentRank == "3"
		CurrentActor.SetActorValue("Confidence", 4.0)
		CurrentRank = "$RDOConfidenceFoolhardy"
	ElseIf CurrentRank == "4"
		CurrentActor.SetActorValue("Confidence", 0.0)
		CurrentRank = "$RDOConfidenceCowardly"
	EndIf
	Return CurrentRank
EndFunction

; Get the assistance of the Actor
String Function RDO_GetActorAssistance(Actor CurrentActor)
	; Get the value as an "int" instead of a "float" for simpler comparisons
	String CurrentRank = CurrentActor.GetActorValue("Assistance") as int
	If CurrentRank == "0"
		CurrentRank = "$RDOAssistanceHelpsNobody"
	ElseIf CurrentRank == "1"
		CurrentRank = "$RDOAssistanceHelpsAllies"
	ElseIf CurrentRank == "2"
		CurrentRank = "$RDOAssistanceHelpsFriendsAndAllies"
	EndIf
	Return CurrentRank
EndFunction

; Set the assistance of the Actor
String Function RDO_SetActorAssistance(Actor CurrentActor)
	; Get the value as an "int" instead of a "float" for simpler comparisons
	String CurrentRank = CurrentActor.GetActorValue("Assistance") as int
	If CurrentRank == "0"
		CurrentActor.SetActorValue("Assistance", 1.0)
		CurrentRank = "$RDOAssistanceHelpsAllies"
	ElseIf CurrentRank == "1"
		CurrentActor.SetActorValue("Assistance", 2.0)
		CurrentRank = "$RDOAssistanceHelpsFriendsAndAllies"
	ElseIf CurrentRank == "2"
		CurrentActor.SetActorValue("Assistance", 0.0)
		CurrentRank = "$RDOAssistanceHelpsNobody"
	EndIf
	Return CurrentRank
EndFunction

; Get the morality of the Actor
String Function RDO_GetActorMorality(Actor CurrentActor)
	; Get the value as an "int" instead of a "float" for simpler comparisons
	String CurrentRank = CurrentActor.GetActorValue("Morality") as int
	If CurrentRank == "0"
		CurrentRank = "$RDOMoralityAnyCrime"
	ElseIf CurrentRank == "1"
		CurrentRank = "$RDOMoralityViolenceAgainstEnemies"
	ElseIf CurrentRank == "2"
		CurrentRank = "$RDOMoralityPropertyCrimeOnly"
	ElseIf CurrentRank == "3"
		CurrentRank = "$RDOMoralityNoCrime"
	EndIf
	Return CurrentRank
EndFunction

; Set the morality of the Actor
String Function RDO_SetActorMorality(Actor CurrentActor)	;renn
	; Get the value as an "int" instead of a "float" for simpler comparisons
	String CurrentRank = CurrentActor.GetActorValue("Morality") as int
	If CurrentRank == "0"
		CurrentActor.SetActorValue("Morality", 1.0)
		CurrentRank = "$RDOMoralityNoCrime"					;"$RDOMoralityViolenceAgainstEnemies"
	ElseIf CurrentRank == "1"
		CurrentActor.SetActorValue("Morality", 2.0)
		CurrentRank = "$RDOMoralityViolenceAgainstEnemies"	;"$RDOMoralityPropertyCrimeOnly"
	ElseIf CurrentRank == "2"
		CurrentActor.SetActorValue("Morality", 3.0)
		CurrentRank = "$RDOMoralityPropertyCrimeOnly"		;"$RDOMoralityNoCrime"
	ElseIf CurrentRank == "3"
		CurrentActor.SetActorValue("Morality", 0.0)
		CurrentRank = "$RDOMoralityAnyCrime"
	EndIf
	Return CurrentRank
EndFunction


; Force Actor to be a Potential Follower
Function RDO_ForcePotentialFollower(Actor CurrentActor)
		
	; To any mod author reading this!
	; A NPC only needs to have a disposition rank of 1 towards the player and be a member of the PotentialFollowerFaction to be recruited as a follower. 
	; So, don't set the disposition rank any higher than 1! It's not needed!
	; Once recruited, their disposition towards the player will be increased to 3 (Ally).
		
	If !CurrentActor.IsInFaction(PotentialFollowerFaction)
		CurrentActor.AddToFaction(PotentialFollowerFaction)	
		If CurrentActor.GetRelationshipRank(PlayerRef) < 1
			CurrentActor.SetRelationShipRank((PlayerRef), 1)
		EndIf
	EndIf
EndFunction


; Force Actor to be a Potential Spouse
Function RDO_ForcePotentialSpouse(Actor CurrentActor)

	; To any mod author reading this!
	; A NPC only needs to have a disposition rank of 1 towards the player and be a member of the PotentialMarriageFaction to be a potential spouse. 
	; So, don't set the disposition rank any higher than 1! It's not needed!
		
	If !CurrentActor.IsInFaction(PotentialMarriageFaction)
		CurrentActor.AddToFaction(PotentialMarriageFaction)
		If CurrentActor.GetRelationshipRank(PlayerRef) < 1
			CurrentActor.SetRelationShipRank((PlayerRef), 1)
		EndIf
	EndIf
EndFunction


; Clear Array of all Actors
Function RDO_ClearActorArray()
	; Clear every element, even the empty ones, just to be sure that nothing was missed
	int NextIndex = 0
	While NextIndex < ActorsPrevented.Length
		ActorsPrevented[NextIndex] = ""
		NextIndex += 1
	EndWhile
EndFunction


; Reset the Index Position
; Example for why this is used: 
; If the user adds 4 actors (pos 0-3) to the array, and then removes the 3rd actor (pos 2).
; Without the below function, when the user adds the 5th actor to the array it will be at pos (4), even though pos (2) is empty.
; This will continue until the user clears all actors, or reaches the maximum number allowed (128).
; This functions fixes the problem by checking each element, starting from the beginning, and then resetting the next pos to the first empty element it finds.

int Function RDO_ResetIndexPosition()
	NextActorIndex = 0
	While NextActorIndex < ActorsPrevented.Length
		If ActorsPrevented[NextActorIndex] == ""
			Return NextActorIndex
		Else
			NextActorIndex += 1
		EndIf
	EndWhile
EndFunction


; Remove a single Actor's name from the list
Actor Function RDO_RemoveActorName(Actor CurrentActor)
	int NextIndex = 0
	While NextIndex < ActorsPrevented.Length
		If !ActorsPrevented[NextIndex] == ""
			If ActorsPrevented[NextIndex] == CurrentActor.GetDisplayName()
				ActorsPrevented[NextIndex] = ""
				; Debug.Trace("RDO: REMOVING FRIEND AT POS " + NextIndex)
				Return CurrentActor
			Else
				NextIndex += 1
			EndIf
		Else
			NextIndex += 1
			; Debug.Trace("RDO: NO ACTOR FOUND - MOVING TO NEXT INDEX")
		EndIf
	EndWhile
EndFunction


; Sorts the list of Actors Prevented
; This will condense the list down so there are no empty elements before any filled elements
Function RDO_SortActorsList()
	int Index1
	int Index2 = ActorsPrevented.Length - 1
		While (Index2 > 0)
			Index1 = 0
			While (Index1 < Index2)
				If (ActorsPrevented[Index1] == "") && !(ActorsPrevented[Index1 + 1] == "")
					String SwapName = ActorsPrevented[Index1] ;CT
					ActorsPrevented[Index1] = ActorsPrevented[Index1 + 1]
					ActorsPrevented[Index1 + 1] = SwapName
				EndIf
				Index1 += 1
			EndWhile
			Index2 -= 1
		EndWhile
		; To ensure that the game has escaped from the nested While loops
		; Debug.Trace("RDO: FINISHED SORTING ACTORS LIST")
EndFunction


; Adds the Actor to Array
Actor Function RDO_SetActorName(Actor CurrentActor)
	While NextActorIndex < ActorsPrevented.Length
		If ActorsPrevented[NextActorIndex] == ""
			; Debug.Trace("RDO: Adding Actor to pos " + NextActorIndex) ; The index position the Actor was Added to
			ActorsPrevented[NextActorIndex] = CurrentActor.GetDisplayName()
			Return CurrentActor
		Else
			NextActorIndex+= 1
		EndIf
	EndWhile
EndFunction


; Revert the list of prevented actors to clear it
; Then clear out the array
Function RDO_ClearAllActors()
	aaa_RDOPreventedActorsList.Revert()
	RDO_ClearActorArray()
EndFunction

; Version of the script
int Function GetVersion()
	; return 1 ; default version
	return 2
EndFunction


;################################################;
;
; MCM Start-up and Options
;
;################################################;

; Everything below this makes up the MCM menu options for RDO
; The menu needs to get started, so use the OnConfigInit() to begin the initialization

Event OnConfigInit()

	; Name of each page in the MCM of the mod
	Pages = new string[6]
	Pages[0] = "$RDOAllFriendlyDialoguePage"
	Pages[1] = "$RDOAllEnemyDialoguePage"
	Pages[2] = "$RDOFollowerIdleDialoguePage"
	Pages[3] = "$RDOChangeSpecificNPCOptionsPage"
	Pages[4] = "$RDOStoppingCombatPage"
	Pages[5] = "$RDOViewNPCStatsPage"
	
	; Initialize Arrays to maximum allowed, 128, in MCM
	ActorsPrevented = new string[128]
	ActorsListIndex = new int[128]
	
	; Just to inform the player that RDO has started up
	Debug.Notification("$RDOStartingUpMsg")
	Debug.Notification("$RDOMCMLoadingMsg")
	
	; When Skyrim Special Edition is released (SSE), many PC mods will likely be re-uploaded to Bethesda.net without permission from the original author
	; One way to help counteract that is to use the statements you see below
	
	If Debug.GetPlatformName() != "Win32"
		Debug.QuitGame()
	EndIf
	
	; This checks what platform the game is being played on
	; If the current platform is on the original Skyrim game for PC, then load everything like normal
	; Otherwise, immediately close the game down without any warning (acts like a CTD)
	; Since OnConfigInit() is a SKSE event, and SSE will not support SKSE immediately, this method will also be added to locations where SKSE is not used
	
	; To make things clear:
	; I'm NOT opposed to console modding, I'm opposed to stolen PC mods for consoles
	; Only the original author, or someone who has been given permission, should upload a PC mod for SSE
	
EndEvent


; When script is updated that adds new content, run this event.
Event OnVersionUpdate(int a_version)
	; a_version is the new version, CurrentVersion is the old version
	If (a_version >=2 && CurrentVersion < 2)
		Debug.Trace(Self + ": Updating script to version 2")
		; Inform the user that a new MCM had been updated
		Debug.Notification("$RDOv1_1MCMUpdateMsg")
	EndIf
EndEvent


Event OnPageReset(string page)
	If (page == "")
		SetTitleText("$RDONoPageTitle")
		LoadCustomContent("RDO/RDOMCMImage.dds", 0.0, 0.0)
		If Debug.GetPlatformName() == "Win32"
			Return
		Else
			Debug.QuitGame()
		EndIf
		Return
	Else
		UnloadCustomContent()	; Make sure to call this so the custom content is removed when the user selects a page
	EndIf
	If (page == "$RDOAllFriendlyDialoguePage")
		SetTitleText("$RDOFriendlyDialogueTitle")
		SetCursorFillMode(TOP_TO_BOTTOM)
		SetCursorPosition(0)
		FriendlyDialogueInfo = AddTextOption("$RDOFriendlyDialogueInfoMsg", "")
		
		SetCursorPosition(12)
		AddHeaderOption("$RDOFemaleVoiceTypesHeader")
		AddToggleOptionST("FArgonianFriend", "$RDOVoiceTypeFemaleArgonian", FemaleArgonianFriendVal)
		AddToggleOptionST("FChildFriend", "$RDOVoiceTypeFemaleChild", FemaleChildFriendVal)
		AddToggleOptionST("FCommanderFriend", "$RDOVoiceTypeFemaleCommander", FemaleCommanderFriendVal)
		AddToggleOptionST("FCommonerFriend", "$RDOVoiceTypeFemaleCommoner", FemaleCommanderFriendVal)
		AddToggleOptionST("FCondescendingFriend", "$RDOVoiceTypeFemaleCondescending", FemaleCondescendingFriendVal)
		AddToggleOptionST("FCowardFriend", "$RDOVoiceTypeFemaleCoward", FemaleCowardFriendVal)
		AddToggleOptionST("FDarkElfFriend", "$RDOVoiceTypeFemaleDarkElf", FemaleDarkElfFriendVal)
		AddToggleOptionST("FElfHaughtyFriend", "$RDOVoiceTypeFemaleElfHaughty", FemaleElfHaughtyFriendVal)
		AddToggleOptionST("FEvenTonedFriend", "$RDOVoiceTypeFemaleEvenToned", FemaleEvenTonedFriendVal)
		AddToggleOptionST("FKhajiitFriend", "$RDOVoiceTypeFemaleKhajiit", FemaleKhajiitFriendVal)
		AddToggleOptionST("FNordFriend", "$RDOVoiceTypeFemaleNord", FemaleNordFriendVal)
		AddToggleOptionST("FOldGrumpyFriend", "$RDOVoiceTypeFemaleOldGrumpy", FemaleOldGrumpyFriendVal)
		AddToggleOptionST("FOldKindlyFriend", "$RDOVoiceTypeFemaleOldKindly", FemaleOldKindlyFriendVal)
		AddToggleOptionST("FOrcFriend", "$RDOVoiceTypeFemaleOrc", FemaleOrcFriendVal)
		AddToggleOptionST("FShrillFriend", "$RDOVoiceTypeFemaleShrill", FemaleShrillFriendVal)
		AddToggleOptionST("FSultryFriend", "$RDOVoiceTypeFemaleSultry", FemaleSultryFriendVal)
		AddToggleOptionST("FYoungEagerFriend", "$RDOVoiceTypeFemaleYoungEager", FemaleYoungEagerFriendVal)
		
		AddEmptyOption()
		
		AddHeaderOption("$RDODawnguardDLCHeader")
		AddToggleOptionST("FSeranaFriend", "$RDOVoiceTypeSerana", FemaleUniqueSeranaFriendVal)
		AddToggleOptionST("FValericaFriend", "$RDOVoiceTypeValerica", FemaleUniqueValericaFriendVal)
		
		AddEmptyOption()
		
		AddHeaderOption("$RDODragonbornDLCHeader")
		AddToggleOptionST("FDarkElfCommonerFriend", "$RDOVoiceTypeFemaleDarkElfCommoner", FemaleDarkElfCommonerFriendVal)
		AddToggleOptionST("FFreaFriend", "$RDOVoiceTypeFrea", FemaleUniqueFreaFriendVal)
		
		SetCursorPosition(5)
		AddHeaderOption("$RDOFriendlyDialogueGuardDialogueHeader")
		ExtraGuardDialogue = AddToggleOption("$RDOFriendlyDialogueGuardDialogue", ExtraGuardDialogueVal)
		
		AddHeaderOption("$RDOFriendlyDialogueHousecarlTradeHeader")
		HSCRLTradeLine = AddToggleOption("$RDOFriendlyDialogueHousecarlTrade", HSCRLTradeLineVal)
		
		SetCursorPosition(4)
		AddHeaderOption("$RDOFriendlyDialogueSpouseDialogueHeader")
		MoreSpouseDialogue = AddToggleOption("$RDOFriendlyDialogueSpouseDialogue", UseSpouseDialogueVal)
		
		AddHeaderOption("$RDOFriendlyDialogueNonSpouseLoverDialogueHeader")
		NonSpouseLoverDialogue = AddToggleOption("$RDOFriendlyDialogueNonSpouseLoverDialogue", NonSpouseLoverDialogueVal)
		
		SetCursorPosition(13)
		AddHeaderOption("$RDOMaleVoiceTypesHeader")
		AddToggleOptionST("MArgonianFriend", "$RDOVoiceTypeMaleArgonian", MaleArgonianFriendVal)
		AddToggleOptionST("MBanditFriend", "$RDOVoiceTypeMaleBandit", MaleBanditFriendVal)
		AddToggleOptionST("MBruteFriend", "$RDOVoiceTypeMaleBrute", MaleBruteFriendVal)
		AddToggleOptionST("MChildFriend", "$RDOVoiceTypeMaleChild", MaleChildFriendVal)
		AddToggleOptionST("MCommanderFriend", "$RDOVoiceTypeMaleCommander", MaleCommanderFriendVal)
		AddToggleOptionST("MCommonerFriend", "$RDOVoiceTypeMaleCommoner", MaleCommonerFriendVal)
		AddToggleOptionST("MCommonerAccentedFriend", "$RDOVoiceTypeMaleCommonerAccented", MaleCommonerAccentedFriendVal)
		AddToggleOptionST("MCondescendingFriend", "$RDOVoiceTypeMaleCondescending", MaleCondescendingFriendVal)
		AddToggleOptionST("MCowardFriend", "$RDOVoiceTypeMaleCoward", MaleCowardFriendVal)
		AddToggleOptionST("MDarkElfFriend", "$RDOVoiceTypeMaleDarkElf", MaleDarkElfFriendVal)
		AddToggleOptionST("MDrunkFriend", "$RDOVoiceTypeMaleDrunk", MaleDrunkFriendVal)
		AddToggleOptionST("MElfHaughtyFriend", "$RDOVoiceTypeMaleElfHaughty", MaleElfHaughtyFriendVal)
		AddToggleOptionST("MEvenTonedFriend", "$RDOVoiceTypeMaleEvenToned", MaleEvenTonedFriendVal)
		AddToggleOptionST("MEvenTonedAccentedFriend", "$RDOVoiceTypeMaleEvenTonedAccented", MaleEvenTonedAccentedFriendVal)
		AddToggleOptionST("MForswornFriend", "$RDOVoiceTypeMaleForsworn", MaleForswornFriendVal)
		AddToggleOptionST("MGuardFriend", "$RDOVoiceTypeMaleGuard", MaleGuardFriendVal)
		AddToggleOptionST("MKhajiitFriend", "$RDOVoiceTypeMaleKhajiit", MaleKhajiitFriendVal)
		AddToggleOptionST("MNordFriend", "$RDOVoiceTypeMaleNord", MaleNordFriendVal)
		AddToggleOptionST("MNordCommanderFriend", "$RDOVoiceTypeMaleNordCommander", MaleNordCommanderFriendVal)
		AddToggleOptionST("MOldGrumpyFriend", "$RDOVoiceTypeMaleOldGrumpy", MaleOldGrumpyFriendVal)
		AddToggleOptionST("MOldKindlyFriend", "$RDOVoiceTypeMaleOldKindly", MaleOldKindlyFriendVal)
		AddToggleOptionST("MOrcFriend", "$RDOVoiceTypeMaleOrc", MaleOrcFriendVal)
		AddToggleOptionST("MSlyCynicalFriend", "$RDOVoiceTypeMaleSlyCynical", MaleSlyCynicalFriendVal)
		AddToggleOptionST("MSoldierFriend", "$RDOVoiceTypeMaleSoldier", MaleSoldierFriendVal)
		AddToggleOptionST("MYoungEagerFriend", "$RDOVoiceTypeMaleYoungEager", MaleYoungEagerFriendVal)
		
		AddEmptyOption()
		
		AddHeaderOption("$RDODragonbornDLCHeader")
		AddToggleOptionST("MDarkElfCommonerFriend", "$RDOVoiceTypeMaleDarkElfCommoner", MaleDarkElfCommonerFriendVal)
		AddToggleOptionST("MDarkElfCynicalFriend", "$RDOVoiceTypeMaleDarkElfCynical", MaleDarkElfCynicalFriendVal)
	
	ElseIf (page == "$RDOAllEnemyDialoguePage")
		SetTitleText("$RDOEnemyDialogueTitle")
		SetCursorFillMode(TOP_TO_BOTTOM)
		SetCursorPosition(0)
		EnemyDialogueInfo = AddTextOption("$RDOEnemyDialogueInfoMsg", "")
		
		SetCursorPosition(12)
		AddHeaderOption("$RDOFemaleVoiceTypesHeader")
		AddToggleOptionST("FArgonianEnemy", "$RDOVoiceTypeFemaleArgonian", FemaleArgonianEnemyVal)
		AddToggleOptionST("FChildEnemy", "$RDOVoiceTypeFemaleChild", FemaleChildEnemyVal)
		AddToggleOptionST("FCommanderEnemy", "$RDOVoiceTypeFemaleCommander", FemaleCommanderEnemyVal)
		AddToggleOptionST("FCommonerEnemy", "$RDOVoiceTypeFemaleCommoner", FemaleCommanderEnemyVal)
		AddToggleOptionST("FCondescendingEnemy", "$RDOVoiceTypeFemaleCondescending", FemaleCondescendingEnemyVal)
		AddToggleOptionST("FCowardEnemy", "$RDOVoiceTypeFemaleCoward", FemaleCowardEnemyVal)
		AddToggleOptionST("FDarkElfEnemy", "$RDOVoiceTypeFemaleDarkElf", FemaleDarkElfEnemyVal)
		AddToggleOptionST("FElfHaughtyEnemy", "$RDOVoiceTypeFemaleElfHaughty", FemaleElfHaughtyEnemyVal)
		AddToggleOptionST("FEvenTonedEnemy", "$RDOVoiceTypeFemaleEvenToned", FemaleEvenTonedEnemyVal)
		AddToggleOptionST("FKhajiitEnemy", "$RDOVoiceTypeFemaleKhajiit", FemaleKhajiitEnemyVal)
		AddToggleOptionST("FNordEnemy", "$RDOVoiceTypeFemaleNord", FemaleNordEnemyVal)
		AddToggleOptionST("FOldGrumpyEnemy", "$RDOVoiceTypeFemaleOldGrumpy", FemaleOldGrumpyEnemyVal)
		AddToggleOptionST("FOldKindlyEnemy", "$RDOVoiceTypeFemaleOldKindly", FemaleOldKindlyEnemyVal)
		AddToggleOptionST("FOrcEnemy", "$RDOVoiceTypeFemaleOrc", FemaleOrcEnemyVal) ;CT
		AddToggleOptionST("FShrillEnemy", "$RDOVoiceTypeFemaleShrill", FemaleShrillEnemyVal)
		AddToggleOptionST("FSultryEnemy", "$RDOVoiceTypeFemaleSultry", FemaleSultryEnemyVal)
		AddToggleOptionST("FYoungEagerEnemy", "$RDOVoiceTypeFemaleYoungEager", FemaleYoungEagerEnemyVal)
		
		AddEmptyOption()
		
		AddHeaderOption("$RDODragonbornDLCHeader")
		AddToggleOptionST("FDarkElfCommonerEnemy", "$RDOVoiceTypeFemaleDarkElfCommoner", FemaleDarkElfCommonerEnemyVal)
		
		SetCursorPosition(1)
		AddHeaderOption("$RDOEnemyDialogueSilentBlockerHeader")
		SilentBlocker = AddToggleOption("$RDOEnemyDialogueSilentBlocker", EnemySilentBlockerVal)
		
		AddHeaderOption("$RDOEnemyDialogueNoVendorServicesHeader")
		NoVendorServices = AddToggleOption("$RDOEnemyDialogueNoVendorServices", EnemyBlockServicesVal)
		
		SetCursorPosition(13)
		AddHeaderOption("$RDOMaleVoiceTypesHeader")
		AddToggleOptionST("MArgonianEnemy", "$RDOVoiceTypeMaleArgonian", MaleArgonianEnemyVal)
		AddToggleOptionST("MBanditEnemy", "$RDOVoiceTypeMaleBandit", MaleBanditEnemyVal)
		AddToggleOptionST("MBruteEnemy", "$RDOVoiceTypeMaleBrute", MaleBruteEnemyVal)
		AddToggleOptionST("MChildEnemy", "$RDOVoiceTypeMaleChild", MaleChildEnemyVal)
		AddToggleOptionST("MCommanderEnemy", "$RDOVoiceTypeMaleCommander", MaleCommanderEnemyVal)
		AddToggleOptionST("MCommonerEnemy", "$RDOVoiceTypeMaleCommoner", MaleCommonerEnemyVal)
		AddToggleOptionST("MCommonerAccentedEnemy", "$RDOVoiceTypeMaleCommonerAccented", MaleCommonerAccentedEnemyVal)
		AddToggleOptionST("MCondescendingEnemy", "$RDOVoiceTypeMaleCondescending", MaleCondescendingEnemyVal)
		AddToggleOptionST("MCowardEnemy", "$RDOVoiceTypeMaleCoward", MaleCowardEnemyVal)
		AddToggleOptionST("MDarkElfEnemy", "$RDOVoiceTypeMaleDarkElf", MaleDarkElfEnemyVal)
		AddToggleOptionST("MDrunkEnemy", "$RDOVoiceTypeMaleDrunk", MaleDrunkEnemyVal) ;CT
		AddToggleOptionST("MElfHaughtyEnemy", "$RDOVoiceTypeMaleElfHaughty", MaleElfHaughtyEnemyVal)
		AddToggleOptionST("MEvenTonedEnemy", "$RDOVoiceTypeMaleEvenToned", MaleEvenTonedEnemyVal)
		AddToggleOptionST("MEvenTonedAccentedEnemy", "$RDOVoiceTypeMaleEvenTonedAccented", MaleEvenTonedAccentedEnemyVal)
		AddToggleOptionST("MForswornEnemy", "$RDOVoiceTypeMaleForsworn", MaleForswornEnemyVal)
		AddToggleOptionST("MGuardEnemy", "$RDOVoiceTypeMaleGuard", MaleGuardEnemyVal)
		AddToggleOptionST("MKhajiitEnemy", "$RDOVoiceTypeMaleKhajiit", MaleKhajiitEnemyVal)
		AddToggleOptionST("MNordEnemy", "$RDOVoiceTypeMaleNord", MaleNordEnemyVal)
		AddToggleOptionST("MNordCommanderEnemy", "$RDOVoiceTypeMaleNordCommander", MaleNordCommanderEnemyVal)
		AddToggleOptionST("MOldGrumpyEnemy", "$RDOVoiceTypeMaleOldGrumpy", MaleOldGrumpyEnemyVal)
		AddToggleOptionST("MOldKindlyEnemy", "$RDOVoiceTypeMaleOldKindly", MaleOldKindlyEnemyVal)
		AddToggleOptionST("MOrcEnemy", "$RDOVoiceTypeMaleOrc", MaleOrcEnemyVal)
		AddToggleOptionST("MSlyCynicalEnemy", "$RDOVoiceTypeMaleSlyCynical", MaleSlyCynicalEnemyVal)
		AddToggleOptionST("MSoldierEnemy", "$RDOVoiceTypeMaleSoldier", MaleSoldierEnemyVal)
		AddToggleOptionST("MYoungEagerEnemy", "$RDOVoiceTypeMaleYoungEager", MaleYoungEagerEnemyVal)
		
		AddEmptyOption()
		
		AddHeaderOption("$RDODragonbornDLCHeader")
		AddToggleOptionST("MDarkElfCommonerEnemy", "$RDOVoiceTypeMaleDarkElfCommoner", MaleDarkElfCommonerEnemyVal)
		AddToggleOptionST("MDarkElfCynicalEnemy", "$RDOVoiceTypeMaleDarkElfCynical", MaleDarkElfCynicalEnemyVal)
	
	ElseIf (page == "$RDOFollowerIdleDialoguePage")
		SetTitleText("$RDOIdleDialogueTitle")
		SetCursorFillMode(TOP_TO_BOTTOM)
		SetCursorPosition(0)
		IdleDialogueInfo = AddTextOption("$RDOIdleDialogueInfoMsg", "")
		
		SetCursorPosition(4)
		AddHeaderOption("$RDOFemaleVoiceTypesHeader")
		AddToggleOptionST("FCommanderIdle", "$RDOVoiceTypeFemaleCommander", FemaleCommanderIdleVal)
		AddToggleOptionST("FCondescendingIdle", "$RDOVoiceTypeFemaleCondescending", FemaleCondescendingIdleVal)
		AddToggleOptionST("FDarkElfIdle", "$RDOVoiceTypeFemaleDarkElf", FemaleDarkElfIdleVal)
		AddToggleOptionST("FElfHaughtyIdle", "$RDOVoiceTypeFemaleElfHaughty", FemaleElfHaughtyIdleVal)
		AddToggleOptionST("FEvenTonedIdle", "$RDOVoiceTypeFemaleEvenToned", FemaleEvenTonedIdleVal)
		AddToggleOptionST("FNordIdle", "$RDOVoiceTypeFemaleNord", FemaleNordIdleVal)
		AddToggleOptionST("FOrcIdle", "$RDOVoiceTypeFemaleOrc", FemaleOrcIdleVal)
		AddToggleOptionST("FSultryIdle", "$RDOVoiceTypeFemaleSultry", FemaleSultryIdleVal)
		AddToggleOptionST("FYoungEagerIdle", "$RDOVoiceTypeFemaleYoungEager", FemaleYoungEagerIdleVal)
		
		AddEmptyOption()
		
		AddHeaderOption("$RDODawnguardDLCHeader")
		AddToggleOptionST("FSeranaIdle", "$RDOVoiceTypeSerana", FemaleUniqueSeranaIdleVal)
		
		AddEmptyOption()
		
		AddHeaderOption("$RDODragonbornDLCHeader")
		AddToggleOptionST("FFreaIdle", "$RDOVoiceTypeFrea", FemaleUniqueFreaIdleVal)
		
		SetCursorPosition(5)
		AddHeaderOption("$RDOMaleVoiceTypesHeader")
		AddToggleOptionST("MArgonianIdle", "$RDOVoiceTypeMaleArgonian", MaleArgonianIdleVal)
		AddToggleOptionST("MBruteIdle", "$RDOVoiceTypeMaleBrute", MaleBruteIdleVal)
		AddToggleOptionST("MDarkElfIdle", "$RDOVoiceTypeMaleDarkElf", MaleDarkElfIdleVal)
		AddToggleOptionST("MDrunkIdle", "$RDOVoiceTypeMaleDrunk", MaleDrunkIdleVal)
		AddToggleOptionST("MEvenTonedIdle", "$RDOVoiceTypeMaleEvenToned", MaleEvenTonedIdleVal)
		AddToggleOptionST("MEvenTonedAccentedIdle", "$RDOVoiceTypeMaleEvenTonedAccented", MaleEvenTonedAccentedIdleVal)
		AddToggleOptionST("MKhajiitIdle", "$RDOVoiceTypeMaleKhajiit", MaleKhajiitIdleVal)
		AddToggleOptionST("MNordIdle", "$RDOVoiceTypeMaleNord", MaleNordIdleVal)
		AddToggleOptionST("MOrcIdle", "$RDOVoiceTypeMaleOrc", MaleOrcIdleVal)
		AddToggleOptionST("MYoungEagerIdle", "$RDOVoiceTypeMaleYoungEager", MaleYoungEagerIdleVal)
		
		AddEmptyOption()
		
		AddHeaderOption("$RDODragonbornDLCHeader")
		AddToggleOptionST("MDarkElfCynicalIdle", "$RDOVoiceTypeMaleDarkElfCynical", MaleDarkElfCynicalIdleVal)
		
		
	ElseIf (page == "$RDOChangeSpecificNPCOptionsPage")
		SetTitleText("$RDOChangeSpecificNPCOptionsTitle")
		SetCursorFillMode(TOP_TO_BOTTOM)
		
		; Get the current Actor the user has selected in their crosshair
		Actor crosshairActor = Game.GetCurrentCrosshairRef() as Actor
		
		; Get the current Actor the user has selected in their console
		Actor consoleActor = Game.GetCurrentConsoleRef() as Actor
		
		; to avoid typing OPTION_FLAG_DISABLED every time it's needed, simply assign it to a variable
		int flags = OPTION_FLAG_DISABLED
		
		If Debug.GetPlatformName() != "Win32"
			Debug.QuitGame()
		EndIf
		
		; If the user has a actor selected in their crosshair, the page will display these options
		If crosshairActor
			AddHeaderOption("$RDONPCSelectedInCrosshairHeader")
			AddTextOption(crosshairActor.GetDisplayName(), "", flags)
			
			AddHeaderOption("$RDOChangeSpecificNPCOptionsDispositionHeader")
			If RDO_IsGenericActorValid(crosshairActor)
				AddTextOptionST("RelationshipRank", crosshairActor.GetDisplayName(), RDO_ShowDisposition(crosshairActor)) 
			Else
				AddTextOptionST("RelationshipRank", "$RDOInvalidActorDisplay", "", flags)
			EndIf
			
			AddHeaderOption("$RDOChangeSpecificNPCOptionsMakeFollowerHeader")
			If RDO_IsActorValidFollower(crosshairActor)
				AddTextOptionST("PotentialFollower", crosshairActor.GetDisplayName(), "$RDOMakeFollowerAcronym")
			Else
				AddTextOptionST("PotentialFollower", crosshairActor.GetDisplayName(), "$RDOInvalidActorDisplay", flags)
			EndIf
			
			AddHeaderOption("$RDOChangeSpecificNPCOptionsMakeSpouseHeader")
			If RDO_IsActorValidSpouse(crosshairActor)
				AddTextOptionST("PotentialSpouse", crosshairActor.GetDisplayName(), "$RDOMakeSpouseAcronym")
			Else
				AddTextOptionST("PotentialSpouse", crosshairActor.GetDisplayName(), "$RDOInvalidActorDisplay", flags)
			EndIf
			
			SetCursorPosition(1)
			AddHeaderOption("$RDOChangeSpecificNPCOptionsPreventActorHeader")
			; Do not allow the user to prevent more actors than the size of the array
			If aaa_RDOPreventedActorsList.GetSize() <= ActorsPrevented.Length ;CT
				; Do let the user "prevent" a NPC from using RDO dialogue if that NPC was already prevented
				If !aaa_RDOPreventedActorsList.HasForm(crosshairActor.GetLeveledActorBase())
					If RDO_IsActorValid(crosshairActor)
						AddTextOptionST("PreventActor", "$RDOConfigNPCPreventActor", crosshairActor.GetDisplayName())
					Else
						AddTextOptionST("PreventActor", "$RDOConfigNPCPreventActor", "$RDONoValidActorDisplay", flags)
					EndIf
				Else
					AddTextOptionST("PreventActor", "$RDOConfigNPCPreventActor", "$RDOAlreadyPreventedDisplay", flags)
				EndIf
			Else
				AddTextOptionST("$RDOMaxNumActorsPreventedDisplay", "", flags)
			EndIf
			
			AddHeaderOption("$RDOChangeSpecificNPCOptionsAllowActorHeader")
			; Do not let the user "allow" a NPC to use RDO dialogue if that NPC was never prevented
			If aaa_RDOPreventedActorsList.HasForm(crosshairActor.GetLeveledActorBase())
				If RDO_IsActorValid(crosshairActor)
					AddTextOptionST("AllowActor", "$RDOConfigNPCAllowActor", crosshairActor.GetDisplayName())
				Else
					AddTextOptionST("AllowActor", "$RDOConfigNPCAllowActor", "$RDONoValidActorDisplay", flags)
				EndIf
			Else
				AddTextOptionST("AllowActor", "$RDOConfigNPCAllowActor", "$RDONeverPreventedDisplay", flags)
			EndIf
			
			AddHeaderOption("$RDOConfigNPCActorsPreventedMenuHeader")
			AddMenuOptionST("ActorsPreventedMenu", "$RDOConfigNPCActorsPreventedMenu", "")
			
			AddHeaderOption("$RDOConfigNPCClearAllActorsHeader")
			; Prevent the user from clearing all actors if no actors have been prevented
			If aaa_RDOPreventedActorsList.GetSize() > 0
				AddTextOptionST("ClearAllActors", "$RDOConfigNPCClearAllActors", "")
			Else
				AddTextOptionST("ClearAllActors", "$RDONoActorsPreventedDisplay", "", flags)
			EndIf
		
		; If there is an actor selected in the console instead, the page will display these options
		ElseIf (consoleActor && consoleActor != PlayerRef)
			AddHeaderOption("$RDONPCSelectedInConsoleHeader")
			AddTextOption(consoleActor.GetDisplayName(), "", flags)
			
			AddHeaderOption("$RDOChangeSpecificNPCOptionsDispositionHeader")
			If RDO_IsGenericActorValid(consoleActor)
				AddTextOptionST("RelationshipRank", consoleActor.GetDisplayName(), RDO_ShowDisposition(consoleActor))
			Else
				AddTextOptionST("RelationshipRank", "$RDOInvalidActorDisplay", "", flags)
			EndIf
			
			AddHeaderOption("$RDOChangeSpecificNPCOptionsMakeFollowerHeader")
			If RDO_IsActorValidFollower(consoleActor)
				AddTextOptionST("PotentialFollower", consoleActor.GetDisplayName(), "$RDOMakeFollowerAcronym")
			Else
				AddTextOptionST("PotentialFollower", consoleActor.GetDisplayName(), "$RDOInvalidActorDisplay", flags)
			EndIf
			
			AddHeaderOption("$RDOChangeSpecificNPCOptionsMakeSpouseHeader")
			If RDO_IsActorValidSpouse(consoleActor)
				AddTextOptionST("PotentialSpouse", consoleActor.GetDisplayName(), "$RDOMakeSpouseAcronym")
			Else
				AddTextOptionST("PotentialSpouse", consoleActor.GetDisplayName(), "$RDOInvalidActorDisplay", flags)
			EndIf
			
			SetCursorPosition(1)
			AddHeaderOption("$RDOChangeSpecificNPCOptionsPreventActorHeader")
			; Do not allow the user to prevent more actors than the size of the array
			If aaa_RDOPreventedActorsList.GetSize() <= ActorsPrevented.Length
				If !aaa_RDOPreventedActorsList.HasForm(consoleActor.GetLeveledActorBase())
					If RDO_IsActorValid(consoleActor)
						AddTextOptionST("PreventActor", "$RDOConfigNPCPreventActor", consoleActor.GetDisplayName())
					Else
						AddTextOptionST("PreventActor", "$RDOConfigNPCPreventActor", "$RDONoValidActorDisplay", flags)
					EndIf
				Else
					AddTextOptionST("PreventActor", "$RDOConfigNPCPreventActor", "$RDOAlreadyPreventedDisplay", flags)
				EndIf
			Else
				AddTextOptionST("PreventActor", "$RDOMaxNumActorsPreventedDisplay", "", flags)
			EndIf
			
			AddHeaderOption("$RDOChangeSpecificNPCOptionsAllowActorHeader")
			; Do not let the user "allow" a NPC to use RDO dialogue if that NPC was never prevented
			If aaa_RDOPreventedActorsList.HasForm(consoleActor.GetLeveledActorBase())
				If RDO_IsActorValid(consoleActor)
					AddTextOptionST("AllowActor", "$RDOConfigNPCAllowActor", consoleActor.GetDisplayName())
				Else
					AddTextOptionST("AllowActor", "$RDOConfigNPCAllowActor", "$RDONoValidActorDisplay", flags)
				EndIf
			Else
				AddTextOptionST("AllowActor", "$RDOConfigNPCAllowActor", "$RDONeverPreventedDisplay", flags)
			EndIf
			
			AddHeaderOption("$RDOConfigNPCActorsPreventedMenuHeader")
			AddMenuOptionST("ActorsPreventedMenu", "$RDOConfigNPCActorsPreventedMenu", "")
			
			AddHeaderOption("$RDOConfigNPCClearAllActorsHeader")
			; Prevent the user from clearing all actors if no actors have been prevented
			If aaa_RDOPreventedActorsList.GetSize() > 0
				AddTextOptionST("ClearAllActors", "$RDOConfigNPCClearAllActors", "")
			Else
				AddTextOptionST("ClearAllActors", "$RDONoActorsPreventedDisplay", "", flags)
			EndIf
		
		; If there's neither a crosshair or console actor selected, the page will display these options
		Else
			AddHeaderOption("$RDOChangeSpecificNPCOptionsNoActorSelectedHeader")
			AddTextOption("$RDONoActorSelectedMsg1", "", flags)
			AddTextOption("$RDONoActorSelectedMsg2", "", flags)
			AddTextOption("$RDONoActorSelectedMsg3", "", flags)
			AddEmptyOption()
			AddTextOption("$RDONoActorSelectedMsg4", "", flags)
			AddTextOption("$RDONoActorSelectedMsg5", "", flags)
			
			SetCursorPosition(1)
			AddHeaderOption("$RDOConfigNPCActorsPreventedMenuHeader")
			AddMenuOptionST("ActorsPreventedMenu", "$RDOConfigNPCActorsPreventedMenu", "")
			
			AddHeaderOption("$RDOConfigNPCClearAllActorsHeader")
			; Prevent the user from clearing all actors if no actors have been prevented
			If aaa_RDOPreventedActorsList.GetSize() > 0
				AddTextOptionST("ClearAllActors", "$RDOConfigNPCClearAllActors", "")
			Else
				AddTextOptionST("ClearAllActors", "$RDONoActorsPreventedDisplay", "", flags)
			EndIf
		EndIf
	ElseIf (page == "$RDOStoppingCombatPage")
		SetTitleText("$RDOStoppingCombatTitle")
		SetCursorFillMode(TOP_TO_BOTTOM)
		SetCursorPosition(0)
		AddHeaderOption("$RDOStoppingCombatStopNPCCombatHeader")
		
		; Using the crosshair reference
		Actor crosshairActor = Game.GetCurrentCrosshairRef() as Actor
		
		; Using the console reference
		Actor consoleActor = Game.GetCurrentConsoleRef() as Actor
		
		; to avoid typing OPTION_FLAG_DISABLED every time it's needed, simply assign it to a variable
		int flags = OPTION_FLAG_DISABLED
		
		; Just as before, the actor selected in the crosshair will get priority over the console
		
		; If there is an actor currently selected under the in-game crosshair
		If crosshairActor
		
			; Check to see if the actor selected in in combat or not
			If crosshairActor.IsInCombat()
				; AddTextOptionST("StopCombat", "$RDOStopCombatMake" + " " + crosshairActor.GetDisplayName() + " " + "$RDOStopCombatStopCombat", "")
				AddTextOptionST("StopCombat", "Make " + crosshairActor.GetDisplayName() + " stop combat", "")
			Else
				; AddTextOptionST("StopCombat", crosshairActor.GetDisplayName() + " " + "$RDOStopCombatNotInCombat", "", flags)
				AddTextOptionST("StopCombat", crosshairActor.GetDisplayName() + " is not in combat", "", flags)
			EndIf
			
		; If there's no crosshair actor selected but there is an actor selected in the console
		ElseIf consoleActor
		
			; Check to see if the actor selected is in combat or not
			If consoleActor.IsInCombat()
				; AddTextOptionST("StopCombat", "$RDOStopCombatMake" + " " + consoleActor.GetDisplayName() + " " + "$RDOStopCombatStopCombat", "")
				AddTextOptionST("StopCombat", "Make " + " " + consoleActor.GetDisplayName() + " stop combat", "")
			Else
				; AddTextOptionST("StopCombat", consoleActor.GetDisplayName() + " " + "$RDOStopCombatNotInCombat", "", flags)
				AddTextOptionST("StopCombat", consoleActor.GetDisplayName() + " is not in combat", "", flags)
			EndIf
			If Debug.GetPlatformName() != "Win32"
				Debug.QuitGame()
			EndIf
		Else
			AddTextOptionST("StopCombat", "$RDONoActorSelected", "", flags)
		EndIf
	
		; If there is an actor currently selected under the in-game crosshair
		If crosshairActor
			
			; Check to see if the actor select is in combat or not
			If crosshairActor.IsInCombat()
				; AddTextOptionST("StopCombatAlarm", "$RDOStopCombatMake" + " " + crosshairActor.GetDisplayName() + " " + "$RDOStopCombatStopAlarm", "")
				AddTextOptionST("StopCombatAlarm", "Make " + " " + crosshairActor.GetDisplayName() + " and enemies stop combat", "")	;renn
			Else
				; AddTextOptionST("StopCombatAlarm", crosshairActor.GetDisplayName() + " " + "$RDOStopCombatNotInCombat", "", flags)
				AddTextOptionST("StopCombatAlarm", crosshairActor.GetDisplayName() + " is not in combat", "", flags)
			EndIf
		
		; If there's no crosshair actor selected but there is an actor selected in the console
		ElseIf consoleActor
		
			; Check to see if the actor selected is in combat or not
			If consoleActor.IsInCombat()
				; AddTextOptionST("StopCombatAlarm", "$RDOStopCombatMake" + " " + consoleActor.GetDisplayName() + " " + "$RDOStopCombatStopAlarm", "")
				AddTextOptionST("StopCombatAlarm", "Make " + " " + consoleActor.GetDisplayName() + " and enemies stop combat", "")
			Else
				; AddTextOptionST("StopCombatAlarm", consoleActor.GetDisplayName() + " " + "$RDOStopCombatNotInCombat", "", flags)
				AddTextOptionST("StopCombatAlarm", consoleActor.GetDisplayName() + " is not in combat", "", flags)
			EndIf
		Else
			AddTextOptionST("StopCombatAlarm", "$RDONoActorSelected", "", flags)
		EndIf
	
		AddHeaderOption("$RDOStopCombatStopAlarmPlayerHeader")
		; Check to see if the player is in combat
		If PlayerRef.IsInCombat() ;SE
			AddTextOptionST("StopCombatAlarmPlayer", "$RDOStopCombatStopAlarmPlayer", "")
		Else
			AddTextOptionST("StopCombatAlarmPlayer", "$RDOStopCombatNotInCombatPlayer", "", flags)
		EndIf
	ElseIf (page == "$RDOViewNPCStatsPage")
		SetTitleText("$RDOViewNPCStatsTitle")
		SetCursorFillMode(TOP_TO_BOTTOM)
		
		; Using the crosshair reference
		Actor crosshairActor = Game.GetCurrentCrosshairRef() as Actor
		
		; Using the console reference
		Actor consoleActor = Game.GetCurrentConsoleRef() as Actor
		
		; to avoid typing OPTION_FLAG_DISABLED every time it's needed, simply assign it to a variable
		int flags = OPTION_FLAG_DISABLED
		
		If crosshairActor
			AddTextOption("$RDONPCSelectedInCrosshairHeader", "")
			AddEmptyOption()
			SetCursorPosition(1)
			AddTextOption(crosshairActor.GetDisplayName(), "", flags)
			AddEmptyOption()
			SetCursorPosition(2)
			AddEmptyOption()
			AddHeaderOption("$RDOViewNPCStatsAllAttributesHeader")
			AddTextOption("$RDOViewNPCStatsDisplayLevel", crosshairActor.GetLevel())
			AddTextOption("$RDOViewNPCStatsDisplayHealth", crosshairActor.GetActorValue("Health") as int)
			AddTextOption("$RDOViewNPCStatsDisplayMagicka", crosshairActor.GetActorValue("Magicka") as int)
			AddTextOption("$RDOViewNPCStatsDisplayStamina", crosshairActor.GetActorValue("Stamina") as int)
			AddHeaderOption("$RDOViewNPCStatsRecoveryHeader")
			AddTextOption("$RDOViewNPCStatsDisplayHealRate", crosshairActor.GetActorValue("HealRateMult") as int +"%")
			AddTextOption("$RDOViewNPCStatsDisplayMagickaRate", crosshairActor.GetActorValue("MagickaRateMult") as int +"%")
			AddTextOption("$RDOViewNPCStatsDisplayStaminaRate", crosshairActor.GetActorValue("StaminaRateMult") as int +"%")
			AddHeaderOption("$RDOViewNPCStatsArmorRatingHeader")
			AddTextOption("$RDOViewNPCStatsDisplayArmorRating", crosshairActor.GetActorValue("DamageResist") as int)
			AddHeaderOption("$RDOViewNPCStatsResistancesHeader")
			AddTextOption("$RDOViewNPCStatsDisplayPoisonResistance", crosshairActor.GetActorValue("PoisonResist") as int +"%")
			AddTextOption("$RDOViewNPCStatsDisplayMagicResistance", crosshairActor.GetActorValue("MagicResist") as int +"%")
			AddTextOption("$RDOViewNPCStatsDisplayFireResistance", crosshairActor.GetActorValue("FireResist") as int +"%")
			AddTextOption("$RDOViewNPCStatsDisplayFrostResistance", crosshairActor.GetActorValue("FrostResist") as int +"%")
			AddTextOption("$RDOViewNPCStatsDisplayShockResistance", crosshairActor.GetActorValue("ElectricResist") as int +"%")
			AddHeaderOption("$RDOViewNPCStatsAIDataHeader")
			AddTextOptionST("AggressionLevel", "$RDOViewNPCStatsDisplayAggression", RDO_GetActorAggression(crosshairActor))
			AddTextOptionST("ConfidenceLevel", "$RDOViewNPCStatsDisplayConfidence", RDO_GetActorConfidence(crosshairActor))
			SetActorMorality = AddTextOption("$RDOViewNPCStatsDisplayMorality", RDO_GetActorMorality(crosshairActor));CT
			SetActorAssistance = AddTextOption("$RDOViewNPCStatsDisplayAssistance", RDO_GetActorAssistance(crosshairActor))
			
			SetCursorPosition(3)
			AddEmptyOption()
			AddHeaderOption("$RDOViewNPCStatsWarriorSkillsHeader")
			AddTextOption("$RDOViewNPCStatsDisplayArchery", crosshairActor.GetActorValue("Marksman") as int)
			AddTextOption("$RDOViewNPCStatsDisplayBlock", crosshairActor.GetActorValue("Block") as int)
			AddTextOption("$RDOViewNPCStatsDisplayHeavyArmor", crosshairActor.GetActorValue("HeavyArmor") as int)
			AddTextOption("$RDOViewNPCStatsDisplayOneHanded", crosshairActor.GetActorValue("OneHanded") as int)
			AddTextOption("$RDOViewNPCStatsDisplaySmithing", crosshairActor.GetActorValue("Smithing") as int)
			AddTextOption("$RDOViewNPCStatsDisplayTwoHanded", crosshairActor.GetActorValue("TwoHanded") as int)
			AddHeaderOption("$RDOViewNPCStatsThiefSkillsHeader")
			AddTextOption("$RDOViewNPCStatsDisplayAlchemy", crosshairActor.GetActorValue("Alchemy") as int)
			AddTextOption("$RDOViewNPCStatsDisplayLightArmor", crosshairActor.GetActorValue("LightArmor") as int)
			AddTextOption("$RDOViewNPCStatsDisplayLockpicking", crosshairActor.GetActorValue("Lockpicking") as int)
			AddTextOption("$RDOViewNPCStatsDisplayPickpocket", crosshairActor.GetActorValue("Pickpocket") as int)
			AddTextOption("$RDOViewNPCStatsDisplaySneak", crosshairActor.GetActorValue("Sneak") as int)
			AddTextOption("$RDOViewNPCStatsDisplaySpeech", crosshairActor.GetActorValue("Speechcraft") as int)
			AddHeaderOption("$RDOViewNPCStatsMagicalSkillsHeader")
			AddTextOption("$RDOViewNPCStatsDisplayAlteration", crosshairActor.GetActorValue("Alteration") as int)
			AddTextOption("$RDOViewNPCStatsDisplayConjuration", crosshairActor.GetActorValue("Conjuration") as int)
			AddTextOption("$RDOViewNPCStatsDisplayDestruction", crosshairActor.GetActorValue("Destruction") as int)
			AddTextOption("$RDOViewNPCStatsDisplayEnchanting", crosshairActor.GetActorValue("Enchanting") as int)
			AddTextOption("$RDOViewNPCStatsDisplayIllusion", crosshairActor.GetActorValue("Illusion") as int)
			AddTextOption("$RDOViewNPCStatsDisplayRestoration", crosshairActor.GetActorValue("Restoration") as int)
		ElseIf (consoleActor && consoleActor != PlayerRef)
			AddTextOption("$RDONPCSelectedInConsoleHeader", "")
			SetCursorPosition(1)
			AddTextOption(consoleActor.GetDisplayName(), "", flags)
			SetCursorPosition(2)
			AddEmptyOption()
			AddHeaderOption("$RDOViewNPCStatsAllAttributesHeader")
			AddTextOption("$RDOViewNPCStatsDisplayLevel", consoleActor.GetLevel())
			AddTextOption("$RDOViewNPCStatsDisplayHealth", consoleActor.GetActorValue("Health") as int)
			AddTextOption("$RDOViewNPCStatsDisplayMagicka", consoleActor.GetActorValue("Magicka") as int)
			AddTextOption("$RDOViewNPCStatsDisplayStamina", consoleActor.GetActorValue("Stamina") as int)
			AddHeaderOption("$RDOViewNPCStatsRecoveryHeader")
			AddTextOption("$RDOViewNPCStatsDisplayHealRate", consoleActor.GetActorValue("HealRateMult") as int +"%")
			AddTextOption("$RDOViewNPCStatsDisplayMagickaRate", consoleActor.GetActorValue("MagickaRateMult") as int +"%")
			AddTextOption("$RDOViewNPCStatsDisplayStaminaRate", consoleActor.GetActorValue("StaminaRateMult") as int +"%")
			AddHeaderOption("$RDOViewNPCStatsArmorRatingHeader")
			AddTextOption("$RDOViewNPCStatsDisplayArmorRating", consoleActor.GetActorValue("DamageResist") as int)
			AddHeaderOption("$RDOViewNPCStatsResistancesHeader")
			AddTextOption("$RDOViewNPCStatsDisplayPoisonResistance", consoleActor.GetActorValue("PoisonResist") as int +"%")
			AddTextOption("$RDOViewNPCStatsDisplayMagicResistance", consoleActor.GetActorValue("MagicResist") as int +"%")
			AddTextOption("$RDOViewNPCStatsDisplayFireResistance", consoleActor.GetActorValue("FireResist") as int +"%") ;SE
			AddTextOption("$RDOViewNPCStatsDisplayFrostResistance", consoleActor.GetActorValue("FrostResist") as int +"%")
			AddTextOption("$RDOViewNPCStatsDisplayShockResistance", consoleActor.GetActorValue("ElectricResist") as int +"%")
			AddHeaderOption("$RDOViewNPCStatsAIDataHeader")
			AddTextOptionST("AggressionLevel", "$RDOViewNPCStatsDisplayAggression", RDO_GetActorAggression(consoleActor))
			AddTextOptionST("ConfidenceLevel", "$RDOViewNPCStatsDisplayConfidence", RDO_GetActorConfidence(consoleActor))
			SetActorMorality = AddTextOption("$RDOViewNPCStatsDisplayMorality", RDO_GetActorMorality(consoleActor))
			SetActorAssistance = AddTextOption("$RDOViewNPCStatsDisplayAssistance", RDO_GetActorAssistance(consoleActor))
			
			SetCursorPosition(3)
			AddEmptyOption()
			AddHeaderOption("$RDOViewNPCStatsWarriorSkillsHeader")
			AddTextOption("$RDOViewNPCStatsDisplayArchery", consoleActor.GetActorValue("Marksman") as int)
			AddTextOption("$RDOViewNPCStatsDisplayBlock", consoleActor.GetActorValue("Block") as int)
			AddTextOption("$RDOViewNPCStatsDisplayHeavyArmor", consoleActor.GetActorValue("HeavyArmor") as int)
			AddTextOption("$RDOViewNPCStatsDisplayOneHanded", consoleActor.GetActorValue("OneHanded") as int)
			AddTextOption("$RDOViewNPCStatsDisplaySmithing", consoleActor.GetActorValue("Smithing") as int)
			AddTextOption("$RDOViewNPCStatsDisplayTwoHanded", consoleActor.GetActorValue("TwoHanded") as int)
			AddHeaderOption("$RDOViewNPCStatsThiefSkillsHeader")
			AddTextOption("$RDOViewNPCStatsDisplayAlchemy", consoleActor.GetActorValue("Alchemy") as int)
			AddTextOption("$RDOViewNPCStatsDisplayLightArmor", consoleActor.GetActorValue("LightArmor") as int)
			AddTextOption("$RDOViewNPCStatsDisplayLockpicking", consoleActor.GetActorValue("Lockpicking") as int)
			AddTextOption("$RDOViewNPCStatsDisplayPickpocket", consoleActor.GetActorValue("Pickpocket") as int)
			AddTextOption("$RDOViewNPCStatsDisplaySneak", consoleActor.GetActorValue("Sneak") as int)
			AddTextOption("$RDOViewNPCStatsDisplaySpeech", consoleActor.GetActorValue("Speechcraft") as int)
			AddHeaderOption("$RDOViewNPCStatsMagicalSkillsHeader")
			AddTextOption("$RDOViewNPCStatsDisplayAlteration", consoleActor.GetActorValue("Alteration") as int)
			AddTextOption("$RDOViewNPCStatsDisplayConjuration", consoleActor.GetActorValue("Conjuration") as int)
			AddTextOption("$RDOViewNPCStatsDisplayDestruction", consoleActor.GetActorValue("Destruction") as int)
			AddTextOption("$RDOViewNPCStatsDisplayEnchanting", consoleActor.GetActorValue("Enchanting") as int)
			AddTextOption("$RDOViewNPCStatsDisplayIllusion", consoleActor.GetActorValue("Illusion") as int)
			AddTextOption("$RDOViewNPCStatsDisplayRestoration", consoleActor.GetActorValue("Restoration") as int)
		Else
			AddHeaderOption("$RDONoActorSelectedHeader")
			AddTextOption("$RDONoActorSelectedMsg1", "", flags)
			AddTextOption("$RDONoActorSelectedMsg2", "", flags)
			AddTextOption("$RDONoActorSelectedMsg3", "", flags)
			AddEmptyOption()
			AddTextOption("$RDONoActorSelectedMsg4", "", flags)
			AddTextOption("$RDONoActorSelectedMsg5", "", flags)
		EndIf
	EndIf
EndEvent


; Several options in the MCM use the default option ID instead of state options
; This is because the MCM script has reached the maximum number of states allowed in one script

Event OnOptionSelect(int option)
	If (option == FriendlyDialogueInfo)
		SetTextOptionValue(FriendlyDialogueInfo, "")
		ShowMessage("$RDOFriendlyDialogueInfoMsgDisplay", false, "$RDOMessageDisplayAccept")
	ElseIf (option == EnemyDialogueInfo)
		SetTextOptionValue(EnemyDialogueInfo, "")
		ShowMessage("$RDOEnemyDialogueInfoMsgDisplay", false, "$RDOMessageDisplayAccept")
	ElseIf (option == IdleDialogueInfo)
		SetTextOptionValue(IdleDialogueInfo, "")
		ShowMessage("$RDOIdleDialogueInfoMsgDisplay", false, "$RDOMessageDisplayAccept")
	ElseIf (option == MoreSpouseDialogue)
		UseSpouseDialogueVal = !UseSpouseDialogueVal
		SetToggleOptionValue(MoreSpouseDialogue, UseSpouseDialogueVal)
	ElseIf (option == ExtraGuardDialogue)
		ExtraGuardDialogueVal = !ExtraGuardDialogueVal
		SetToggleOptionValue(ExtraGuardDialogue, ExtraGuardDialogueVal)
	ElseIf (option == HSCRLTradeLine)
		HSCRLTradeLineVal = !HSCRLTradeLineVal
		SetToggleOptionValue(HSCRLTradeLine, HSCRLTradeLineVal)
	ElseIf (option == SilentBlocker)
		EnemySilentBlockerVal = !EnemySilentBlockerVal
		SetToggleOptionValue(SilentBlocker, EnemySilentBlockerVal)
	ElseIf (option == NoVendorServices)
		EnemyBlockServicesVal = !EnemyBlockServicesVal
		SetToggleOptionValue(NoVendorServices, EnemyBlockServicesVal)
		If EnemyBlockServicesVal == True
			a_RDOBlockRivalServices.SetValue(1)
		Else
			a_RDOBlockRivalServices.SetValue(0)
		EndIf
	ElseIf (option == SetActorMorality)
		Actor crosshairActor = Game.GetCurrentCrosshairRef() as Actor
		Actor consoleActor = Game.GetCurrentConsoleRef() as Actor
		If crosshairActor
			SetTextOptionValue(SetActorMorality, RDO_SetActorMorality(crosshairActor))
		ElseIf consoleActor
			SetTextOptionValue(SetActorMorality, RDO_SetActorMorality(consoleActor))
		EndIf
	ElseIf (option == SetActorAssistance)
		Actor crosshairActor = Game.GetCurrentCrosshairRef() as Actor
		Actor consoleActor = Game.GetCurrentConsoleRef() as Actor
		If crosshairActor
			SetTextOptionValue(SetActorAssistance, RDO_SetActorAssistance(crosshairActor))
		ElseIf consoleActor
			SetTextOptionValue(SetActorAssistance, RDO_SetActorAssistance(consoleActor))
		EndIf
	ElseIf (option == NonSpouseLoverDialogue)
		NonSpouseLoverDialogueVal = !NonSpouseLoverDialogueVal
		SetToggleOptionValue(NonSpouseLoverDialogue, NonSpouseLoverDialogueVal)
	EndIf
EndEvent

Event OnOptionHighlight(int option)
	If (option == MoreSpouseDialogue)
		SetInfoText("$RDOUseSpouseDialogueMsg")
	ElseIf (option == ExtraGuardDialogue)
		SetInfoText("$RDOExtraGuardDialogueMsg")
	ElseIf (option == HSCRLTradeLine)
		SetInfoText("$RDOHousecarlTradeLineMsg")
	ElseIf (option == SilentBlocker)
		SetInfoText("$RDOEnemySilentBlockerMsg")
	ElseIf (option == NoVendorServices)
		SetInfoText("$RDOEnemyBlockServicesMsg")
	ElseIf (option == SetActorMorality)
		SetInfoText("$RDOMoralityInfoMsg")
	ElseIf (option == SetActorAssistance)
		SetInfoText("$RDOAssistanceInfoMsg")
	ElseIf (option == NonSpouseLoverDialogue)
		SetInfoText("$RDONonSpouseLoverDialogueInfoMsg")
	EndIf
EndEvent

;;;;;;;;;;;;;;;;;;;;;;
; Female Friend States
;;;;;;;;;;;;;;;;;;;;;;

State FArgonianFriend
	Event OnSelectST()
		FemaleArgonianFriendVal = !FemaleArgonianFriendVal
		SetToggleOptionValueST(FemaleArgonianFriendVal)
	EndEvent
	Event OnHighlightST()	;=====renn
		SetInfoText("FemaleArgonian-")
	EndEvent
EndState

State FChildFriend
	Event OnSelectST()
		FemaleChildFriendVal = !FemaleChildFriendVal
		SetToggleOptionValueST(FemaleChildFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleChild-")
	EndEvent
EndState

State FCommanderFriend
	Event OnSelectST()
		FemaleCommanderFriendVal = !FemaleCommanderFriendVal
		SetToggleOptionValueST(FemaleCommanderFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleCommander-")
	EndEvent
EndState

State FCommonerFriend
	Event OnSelectST()
		FemaleCommonerFriendVal = !FemaleCommonerFriendVal
		SetToggleOptionValueST(FemaleCommonerFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleCommoner-")
	EndEvent
EndState

State FCondescendingFriend
	Event OnSelectST()
		FemaleCondescendingFriendVal = !FemaleCondescendingFriendVal
		SetToggleOptionValueST(FemaleCondescendingFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleCondescending-")
	EndEvent
EndState

State FCowardFriend
	Event OnSelectST()
		FemaleCowardFriendVal = !FemaleCowardFriendVal
		SetToggleOptionValueST(FemaleCowardFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleCoward-")
	EndEvent
EndState

State FDarkElfFriend
	Event OnSelectST()
		FemaleDarkElfFriendVal = !FemaleDarkElfFriendVal
		SetToggleOptionValueST(FemaleDarkElfFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleDarkElf-")
	EndEvent
EndState

State FDarkElfCommonerFriend
	Event OnSelectST()
		FemaleDarkElfCommonerFriendVal = !FemaleDarkElfCommonerFriendVal
		SetToggleOptionValueST(FemaleDarkElfCommonerFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleDarkElfCommoner-")
	EndEvent
EndState

State FElfHaughtyFriend
	Event OnSelectST()
		FemaleElfHaughtyFriendVal = !FemaleElfHaughtyFriendVal
		SetToggleOptionValueST(FemaleElfHaughtyFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleElfHaughty-")
	EndEvent
EndState

State FEvenTonedFriend
	Event OnSelectST()
		FemaleEvenTonedFriendVal = !FemaleEvenTonedFriendVal
		SetToggleOptionValueST(FemaleEvenTonedFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleEvenToned-")
	EndEvent
EndState

State FKhajiitFriend
	Event OnSelectST()
		FemaleKhajiitFriendVal = !FemaleKhajiitFriendVal
		SetToggleOptionValueST(FemaleKhajiitFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleKhajiit-")
	EndEvent
EndState

State FNordFriend
	Event OnSelectST()
		FemaleNordFriendVal = !FemaleNordFriendVal
		SetToggleOptionValueST(FemaleNordFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleNord-")
	EndEvent
EndState

State FOldGrumpyFriend
	Event OnSelectST()
		FemaleOldGrumpyFriendVal = !FemaleOldGrumpyFriendVal
		SetToggleOptionValueST(FemaleOldGrumpyFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleOldGrumpy-")
	EndEvent
EndState

State FOldKindlyFriend
	Event OnSelectST()
		FemaleOldKindlyFriendVal = !FemaleOldKindlyFriendVal
		SetToggleOptionValueST(FemaleOldKindlyFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleOldKindly-")
	EndEvent
EndState

State FOrcFriend
	Event OnSelectST()
		FemaleOrcFriendVal = !FemaleOrcFriendVal
		SetToggleOptionValueST(FemaleOrcFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleOrc-")
	EndEvent
EndState

State FShrillFriend
	Event OnSelectST()
		FemaleShrillFriendVal = !FemaleShrillFriendVal
		SetToggleOptionValueST(FemaleShrillFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleShrill-")
	EndEvent
EndState

State FSultryFriend
	Event OnSelectST()
		FemaleSultryFriendVal = !FemaleSultryFriendVal
		SetToggleOptionValueST(FemaleSultryFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleSultry-")
	EndEvent
EndState

State FYoungEagerFriend
	Event OnSelectST()
		FemaleYoungEagerFriendVal = !FemaleYoungEagerFriendVal
		SetToggleOptionValueST(FemaleYoungEagerFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleYoungEager-")
	EndEvent
EndState

State FFreaFriend
	Event OnSelectST()
		FemaleUniqueFreaFriendVal = !FemaleUniqueFreaFriendVal
		SetToggleOptionValueST(FemaleUniqueFreaFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("-")
	EndEvent
EndState

State FSeranaFriend
	Event OnSelectST()
		FemaleUniqueSeranaFriendVal = !FemaleUniqueSeranaFriendVal
		SetToggleOptionValueST(FemaleUniqueSeranaFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("-")
	EndEvent
EndState

State FValericaFriend
	Event OnSelectST()
		FemaleUniqueValericaFriendVal = !FemaleUniqueValericaFriendVal
		SetToggleOptionValueST(FemaleUniqueValericaFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("-")
	EndEvent
EndState

;;;;;;;;;;;;;;;;;;;;;
; Male Friend States
;;;;;;;;;;;;;;;;;;;;;

State MArgonianFriend
	Event OnSelectST()
		MaleArgonianFriendVal = !MaleArgonianFriendVal
		SetToggleOptionValueST(MaleArgonianFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleArgonian-")
	EndEvent
EndState

State MBanditFriend
	Event OnSelectST()
		MaleBanditFriendVal = !MaleBanditFriendVal
		SetToggleOptionValueST(MaleBanditFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleBandit-")
	EndEvent
EndState

State MBruteFriend
	Event OnSelectST()
		MaleBruteFriendVal = !MaleBruteFriendVal
		SetToggleOptionValueST(MaleBruteFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleBrute-")
	EndEvent
EndState

State MChildFriend
	Event OnSelectST()
		MaleChildFriendVal = !MaleChildFriendVal
		SetToggleOptionValueST(MaleChildFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleChild-")
	EndEvent
EndState

State MCommanderFriend
	Event OnSelectST()
		MaleCommanderFriendVal = !MaleCommanderFriendVal
		SetToggleOptionValueST(MaleCommanderFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleCommander-")
	EndEvent
EndState

State MCommonerFriend
	Event OnSelectST()
		MaleCommonerFriendVal = !MaleCommonerFriendVal
		SetToggleOptionValueST(MaleCommonerFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleCommoner-")
	EndEvent
EndState

State MCommonerAccentedFriend
	Event OnSelectST()
		MaleCommonerAccentedFriendVal = !MaleCommonerAccentedFriendVal
		SetToggleOptionValueST(MaleCommonerAccentedFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleCommonerAccented-")
	EndEvent
EndState

State MCondescendingFriend
	Event OnSelectST()
		MaleCondescendingFriendVal = !MaleCondescendingFriendVal
		SetToggleOptionValueST(MaleCondescendingFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleCondescending-")
	EndEvent
EndState

State MCowardFriend
	Event OnSelectST()
		MaleCowardFriendVal = !MaleCowardFriendVal
		SetToggleOptionValueST(MaleCowardFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleCoward-")
	EndEvent
EndState

State MDarkElfFriend
	Event OnSelectST()
		MaleDarkElfFriendVal = !MaleDarkElfFriendVal
		SetToggleOptionValueST(MaleDarkElfFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleDarkElf-")
	EndEvent
EndState

State MDarkElfCommonerFriend
	Event OnSelectST()
		MaleDarkElfCommonerFriendVal = !MaleDarkElfCommonerFriendVal
		SetToggleOptionValueST(MaleDarkElfCommonerFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleDarkElfCommoner-")
	EndEvent
EndState

State MDarkElfCynicalFriend
	Event OnSelectST()
		MaleDarkElfCynicalFriendVal = !MaleDarkElfCynicalFriendVal
		SetToggleOptionValueST(MaleDarkElfCynicalFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleDarkElfCynical-")
	EndEvent
EndState

State MDrunkFriend
	Event OnSelectST()
		MaleDrunkFriendVal = !MaleDrunkFriendVal
		SetToggleOptionValueST(MaleDrunkFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleDrunk-")
	EndEvent
EndState

State MElfHaughtyFriend
	Event OnSelectST()
		MaleElfHaughtyFriendVal = !MaleElfHaughtyFriendVal
		SetToggleOptionValueST(MaleElfHaughtyFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleElfHaughty-")
	EndEvent
EndState

State MEvenTonedFriend
	Event OnSelectST()
		MaleEvenTonedFriendVal = !MaleEvenTonedFriendVal
		SetToggleOptionValueST(MaleEvenTonedFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleEvenToned-")
	EndEvent
EndState

State MEvenTonedAccentedFriend
	Event OnSelectST()
		MaleEvenTonedAccentedFriendVal = !MaleEvenTonedAccentedFriendVal
		SetToggleOptionValueST(MaleEvenTonedAccentedFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleEvenTonedAccented-")
	EndEvent
EndState

State MForswornFriend
	Event OnSelectST()
		MaleForswornFriendVal = !MaleForswornFriendVal
		SetToggleOptionValueST(MaleForswornFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleForsworn-")
	EndEvent
EndState

State MGuardFriend
	Event OnSelectST()
		MaleGuardFriendVal = !MaleGuardFriendVal
		SetToggleOptionValueST(MaleGuardFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleGuard-")
	EndEvent
EndState

State MKhajiitFriend
	Event OnSelectST()
		MaleKhajiitFriendVal = !MaleKhajiitFriendVal
		SetToggleOptionValueST(MaleKhajiitFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleKhajiit-")
	EndEvent
EndState

State MNordFriend
	Event OnSelectST()
		MaleNordFriendVal = !MaleNordFriendVal
		SetToggleOptionValueST(MaleNordFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleNord-")
	EndEvent
EndState

State MNordCommanderFriend
	Event OnSelectST()
		MaleNordCommanderFriendVal = !MaleNordCommanderFriendVal
		SetToggleOptionValueST(MaleNordCommanderFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleNordCommander-")
	EndEvent
EndState

State MOldGrumpyFriend
	Event OnSelectST()
		MaleOldGrumpyFriendVal = !MaleOldGrumpyFriendVal
		SetToggleOptionValueST(MaleOldGrumpyFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleOldGrumpy-")
	EndEvent
EndState

State MOldKindlyFriend
	Event OnSelectST()
		MaleOldKindlyFriendVal = !MaleOldKindlyFriendVal
		SetToggleOptionValueST(MaleOldKindlyFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleOldKindly-")
	EndEvent
EndState

State MOrcFriend
	Event OnSelectST()
		MaleOrcFriendVal = !MaleOrcFriendVal
		SetToggleOptionValueST(MaleOrcFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleOrc-")
	EndEvent
EndState

State MSlyCynicalFriend
	Event OnSelectST()
		MaleSlyCynicalFriendVal = !MaleSlyCynicalFriendVal
		SetToggleOptionValueST(MaleSlyCynicalFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleSlyCynical-")
	EndEvent
EndState

State MSoldierFriend
	Event OnSelectST()
		MaleSoldierFriendVal = !MaleSoldierFriendVal
		SetToggleOptionValueST(MaleSoldierFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleSoldier-")
	EndEvent
EndState

State MYoungEagerFriend
	Event OnSelectST()
		MaleYoungEagerFriendVal = !MaleYoungEagerFriendVal
		SetToggleOptionValueST(MaleYoungEagerFriendVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleYoungEager-")
	EndEvent
EndState

;;;;;;;;;;;;;;;;;;;;;;
; Female Enemy States
;;;;;;;;;;;;;;;;;;;;;;

State FArgonianEnemy
	Event OnSelectST()
		FemaleArgonianEnemyVal = !FemaleArgonianEnemyVal
		SetToggleOptionValueST(FemaleArgonianEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleArgonian-")
	EndEvent
EndState

State FChildEnemy
	Event OnSelectST()
		FemaleChildEnemyVal = !FemaleChildEnemyVal
		SetToggleOptionValueST(FemaleChildEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleChild-")
	EndEvent
EndState

State FCommanderEnemy
	Event OnSelectST()
		FemaleCommanderEnemyVal = !FemaleCommanderEnemyVal
		SetToggleOptionValueST(FemaleCommanderEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleCommander-")
	EndEvent
EndState

State FCommonerEnemy
	Event OnSelectST()
		FemaleCommonerEnemyVal = !FemaleCommonerEnemyVal
		SetToggleOptionValueST(FemaleCommonerEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleCommoner-")
	EndEvent
EndState

State FCondescendingEnemy
	Event OnSelectST()
		FemaleCondescendingEnemyVal = !FemaleCondescendingEnemyVal
		SetToggleOptionValueST(FemaleCondescendingEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleCondescending-")
	EndEvent
EndState

State FCowardEnemy
	Event OnSelectST()
		FemaleCowardEnemyVal = !FemaleCowardEnemyVal
		SetToggleOptionValueST(FemaleCowardEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleCoward-")
	EndEvent
EndState

State FDarkElfEnemy
	Event OnSelectST()
		FemaleDarkElfEnemyVal = !FemaleDarkElfEnemyVal
		SetToggleOptionValueST(FemaleDarkElfEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleDarkElf-")
	EndEvent
EndState

State FDarkElfCommonerEnemy
	Event OnSelectST()
		FemaleDarkElfCommonerEnemyVal = !FemaleDarkElfCommonerEnemyVal
		SetToggleOptionValueST(FemaleDarkElfCommonerEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleDarkElfCommoner-")
	EndEvent
EndState

State FElfHaughtyEnemy
	Event OnSelectST()
		FemaleElfHaughtyEnemyVal = !FemaleElfHaughtyEnemyVal
		SetToggleOptionValueST(FemaleElfHaughtyEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleElfHaughty-")
	EndEvent
EndState

State FEvenTonedEnemy
	Event OnSelectST()
		FemaleEvenTonedEnemyVal = !FemaleEvenTonedEnemyVal
		SetToggleOptionValueST(FemaleEvenTonedEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleEvenToned-")
	EndEvent
EndState

State FKhajiitEnemy
	Event OnSelectST()
		FemaleKhajiitEnemyVal = !FemaleKhajiitEnemyVal
		SetToggleOptionValueST(FemaleKhajiitEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleKhajiit-")
	EndEvent
EndState

State FNordEnemy
	Event OnSelectST()
		FemaleNordEnemyVal = !FemaleNordEnemyVal
		SetToggleOptionValueST(FemaleNordEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleNord-")
	EndEvent
EndState

State FOldGrumpyEnemy
	Event OnSelectST()
		FemaleOldGrumpyEnemyVal = !FemaleOldGrumpyEnemyVal
		SetToggleOptionValueST(FemaleOldGrumpyEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleOldGrumpy-")
	EndEvent
EndState

State FOldKindlyEnemy
	Event OnSelectST()
		FemaleOldKindlyEnemyVal = !FemaleOldKindlyEnemyVal
		SetToggleOptionValueST(FemaleOldKindlyEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleOldKindly-")
	EndEvent
EndState

State FOrcEnemy
	Event OnSelectST()
		FemaleOrcEnemyVal = !FemaleOrcEnemyVal
		SetToggleOptionValueST(FemaleOrcEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleOrc-")
	EndEvent
EndState

State FShrillEnemy
	Event OnSelectST()
		FemaleShrillEnemyVal = !FemaleShrillEnemyVal
		SetToggleOptionValueST(FemaleShrillEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleShrill-")
	EndEvent
EndState

State FSultryEnemy
	Event OnSelectST()
		FemaleSultryEnemyVal = !FemaleSultryEnemyVal
		SetToggleOptionValueST(FemaleSultryEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleSultry-")
	EndEvent
EndState

State FYoungEagerEnemy
	Event OnSelectST()
		FemaleYoungEagerEnemyVal = !FemaleYoungEagerEnemyVal
		SetToggleOptionValueST(FemaleYoungEagerEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleYoungEager-")
	EndEvent
EndState

;;;;;;;;;;;;;;;;;;;;;
; Male Enemy States
;;;;;;;;;;;;;;;;;;;;;

State MArgonianEnemy
	Event OnSelectST()
		MaleArgonianEnemyVal = !MaleArgonianEnemyVal
		SetToggleOptionValueST(MaleArgonianEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleArgonian-")
	EndEvent
EndState

State MBanditEnemy
	Event OnSelectST()
		MaleBanditEnemyVal = !MaleBanditEnemyVal
		SetToggleOptionValueST(MaleBanditEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleBandit-")
	EndEvent
EndState

State MBruteEnemy
	Event OnSelectST()
		MaleBruteEnemyVal = !MaleBruteEnemyVal
		SetToggleOptionValueST(MaleBruteEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleBrute-")
	EndEvent
EndState

State MChildEnemy
	Event OnSelectST()
		MaleChildEnemyVal = !MaleChildEnemyVal
		SetToggleOptionValueST(MaleChildEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleChild-")
	EndEvent
EndState

State MCommanderEnemy
	Event OnSelectST()
		MaleCommanderEnemyVal = !MaleCommanderEnemyVal
		SetToggleOptionValueST(MaleCommanderEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleCommander-")
	EndEvent
EndState

State MCommonerEnemy
	Event OnSelectST()
		MaleCommonerEnemyVal = !MaleCommonerEnemyVal
		SetToggleOptionValueST(MaleCommonerEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleCommoner-")
	EndEvent
EndState

State MCommonerAccentedEnemy
	Event OnSelectST()
		MaleCommonerAccentedEnemyVal = !MaleCommonerAccentedEnemyVal
		SetToggleOptionValueST(MaleCommonerAccentedEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleCommonerAccented-")
	EndEvent
EndState

State MCondescendingEnemy
	Event OnSelectST()
		MaleCondescendingEnemyVal = !MaleCondescendingEnemyVal
		SetToggleOptionValueST(MaleCondescendingEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleCondescending-")
	EndEvent
EndState

State MCowardEnemy
	Event OnSelectST()
		MaleCowardEnemyVal = !MaleCowardEnemyVal
		SetToggleOptionValueST(MaleCowardEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleCoward-")
	EndEvent
EndState

State MDarkElfEnemy
	Event OnSelectST()
		MaleDarkElfEnemyVal = !MaleDarkElfEnemyVal
		SetToggleOptionValueST(MaleDarkElfEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleDarkElf-")
	EndEvent
EndState

State MDarkElfCommonerEnemy
	Event OnSelectST()
		MaleDarkElfCommonerEnemyVal = !MaleDarkElfCommonerEnemyVal
		SetToggleOptionValueST(MaleDarkElfCommonerEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleDarkElfCommoner-")
	EndEvent
EndState

State MDarkElfCynicalEnemy
	Event OnSelectST()
		MaleDarkElfCynicalEnemyVal = !MaleDarkElfCynicalEnemyVal
		SetToggleOptionValueST(MaleDarkElfCynicalEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleDarkElfCynical-")
	EndEvent
EndState

State MDrunkEnemy
	Event OnSelectST()
		MaleDrunkEnemyVal = !MaleDrunkEnemyVal
		SetToggleOptionValueST(MaleDrunkEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleDrunk-")
	EndEvent
EndState

State MElfHaughtyEnemy
	Event OnSelectST()
		MaleElfHaughtyEnemyVal = !MaleElfHaughtyEnemyVal
		SetToggleOptionValueST(MaleElfHaughtyEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleElfHaughty-")
	EndEvent
EndState

State MEvenTonedEnemy
	Event OnSelectST()
		MaleEvenTonedEnemyVal = !MaleEvenTonedEnemyVal
		SetToggleOptionValueST(MaleEvenTonedEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleEvenToned-")
	EndEvent
EndState

State MEvenTonedAccentedEnemy
	Event OnSelectST()
		MaleEvenTonedAccentedEnemyVal = !MaleEvenTonedAccentedEnemyVal
		SetToggleOptionValueST(MaleEvenTonedAccentedEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleEvenTonedAccented-")
	EndEvent
EndState

State MForswornEnemy
	Event OnSelectST()
		MaleForswornEnemyVal = !MaleForswornEnemyVal
		SetToggleOptionValueST(MaleForswornEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleForsworn-")
	EndEvent
EndState

State MGuardEnemy
	Event OnSelectST()
		MaleGuardEnemyVal = !MaleGuardEnemyVal
		SetToggleOptionValueST(MaleGuardEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleGuard-")
	EndEvent
EndState

State MKhajiitEnemy
	Event OnSelectST()
		MaleKhajiitEnemyVal = !MaleKhajiitEnemyVal
		SetToggleOptionValueST(MaleKhajiitEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleKhajiit-")
	EndEvent
EndState

State MNordEnemy
	Event OnSelectST()
		MaleNordEnemyVal = !MaleNordEnemyVal
		SetToggleOptionValueST(MaleNordEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleNord-")
	EndEvent
EndState

State MNordCommanderEnemy
	Event OnSelectST()
		MaleNordCommanderEnemyVal = !MaleNordCommanderEnemyVal
		SetToggleOptionValueST(MaleNordCommanderEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleNordCommander-")
	EndEvent
EndState

State MOldGrumpyEnemy
	Event OnSelectST()
		MaleOldGrumpyEnemyVal = !MaleOldGrumpyEnemyVal
		SetToggleOptionValueST(MaleOldGrumpyEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleOldGrumpy-")
	EndEvent
EndState

State MOldKindlyEnemy
	Event OnSelectST()
		MaleOldKindlyEnemyVal = !MaleOldKindlyEnemyVal
		SetToggleOptionValueST(MaleOldKindlyEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleOldKindly-")
	EndEvent
EndState

State MOrcEnemy
	Event OnSelectST()
		MaleOrcEnemyVal = !MaleOrcEnemyVal
		SetToggleOptionValueST(MaleOrcEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleOrc-")
	EndEvent
EndState

State MSlyCynicalEnemy
	Event OnSelectST()
		MaleSlyCynicalEnemyVal = !MaleSlyCynicalEnemyVal
		SetToggleOptionValueST(MaleSlyCynicalEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleSlyCynical-")
	EndEvent
EndState

State MSoldierEnemy
	Event OnSelectST()
		MaleSoldierEnemyVal = !MaleSoldierEnemyVal
		SetToggleOptionValueST(MaleSoldierEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleSoldier-")
	EndEvent
EndState

State MYoungEagerEnemy
	Event OnSelectST()
		MaleYoungEagerEnemyVal = !MaleYoungEagerEnemyVal
		SetToggleOptionValueST(MaleYoungEagerEnemyVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleYoungEager-")
	EndEvent
EndState

;;;;;;;;;;;;;;;;;;;;
; Female Idle States
;;;;;;;;;;;;;;;;;;;;

State FCommanderIdle
	Event OnSelectST()
		FemaleCommanderIdleVal = !FemaleCommanderIdleVal
		SetToggleOptionValueST(FemaleCommanderIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleCommander-")
	EndEvent
EndState

State FCondescendingIdle
	Event OnSelectST()
		FemaleCondescendingIdleVal = !FemaleCondescendingIdleVal
		SetToggleOptionValueST(FemaleCondescendingIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleCondescending-")
	EndEvent
EndState

State FDarkElfIdle
	Event OnSelectST()
		FemaleDarkElfIdleVal = !FemaleDarkElfIdleVal
		SetToggleOptionValueST(FemaleDarkElfIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleDarkElf-")
	EndEvent
EndState

State FElfHaughtyIdle
	Event OnSelectST()
		FemaleElfHaughtyIdleVal = !FemaleElfHaughtyIdleVal
		SetToggleOptionValueST(FemaleElfHaughtyIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleElfHaughty-")
	EndEvent
EndState

State FEvenTonedIdle
	Event OnSelectST()
		FemaleEvenTonedIdleVal = !FemaleEvenTonedIdleVal
		SetToggleOptionValueST(FemaleEvenTonedIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleEvenToned-")
	EndEvent
EndState

State FFreaIdle
	Event OnSelectST()
		FemaleUniqueFreaIdleVal = !FemaleUniqueFreaIdleVal
		SetToggleOptionValueST(FemaleUniqueFreaIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("-")
	EndEvent
EndState

State FNordIdle
	Event OnSelectST()
		FemaleNordIdleVal = !FemaleNordIdleVal
		SetToggleOptionValueST(FemaleNordIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleNord-")
	EndEvent
EndState

State FOrcIdle
	Event OnSelectST()
		FemaleOrcIdleVal = !FemaleOrcIdleVal
		SetToggleOptionValueST(FemaleOrcIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleOrc-")
	EndEvent
EndState

State FSeranaIdle
	Event OnSelectST()
		FemaleUniqueSeranaIdleVal = !FemaleUniqueSeranaIdleVal
		SetToggleOptionValueST(FemaleUniqueSeranaIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("-")
	EndEvent
EndState

State FSultryIdle
	Event OnSelectST()
		FemaleSultryIdleVal = !FemaleSultryIdleVal
		SetToggleOptionValueST(FemaleSultryIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleSultry-")
	EndEvent
EndState

State FYoungEagerIdle
	Event OnSelectST()
		FemaleYoungEagerIdleVal = !FemaleYoungEagerIdleVal
		SetToggleOptionValueST(FemaleYoungEagerIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("FemaleYoungEager-")
	EndEvent
EndState

;;;;;;;;;;;;;;;;;;
; Male Idle States
;;;;;;;;;;;;;;;;;;

State MArgonianIdle
	Event OnSelectST()
		MaleArgonianIdleVal = !MaleArgonianIdleVal
		SetToggleOptionValueST(MaleArgonianIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleArgonian-")
	EndEvent
EndState

State MBruteIdle
	Event OnSelectST()
		MaleBruteIdleVal = !MaleBruteIdleVal
		SetToggleOptionValueST(MaleBruteIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleBrute-")
	EndEvent
EndState

State MDarkElfCynicalIdle
	Event OnSelectST()
		MaleDarkElfCynicalIdleVal = !MaleDarkElfCynicalIdleVal
		SetToggleOptionValueST(MaleDarkElfCynicalIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleDarkElfCynical-")
	EndEvent
EndState

State MDarkElfIdle
	Event OnSelectST()
		MaleDarkElfIdleVal = !MaleDarkElfIdleVal
		SetToggleOptionValueST(MaleDarkElfIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleDarkElf-")
	EndEvent
EndState

State MDrunkIdle
	Event OnSelectST()
		MaleDrunkIdleVal = !MaleDrunkIdleVal
		SetToggleOptionValueST(MaleDrunkIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleDrunk-")
	EndEvent
EndState

State MEvenTonedIdle
	Event OnSelectST()
		MaleEvenTonedIdleVal = !MaleEvenTonedIdleVal
		SetToggleOptionValueST(MaleEvenTonedIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleEvenToned-")
	EndEvent
EndState

State MEvenTonedAccentedIdle
	Event OnSelectST()
		MaleEvenTonedAccentedIdleVal = !MaleEvenTonedAccentedIdleVal
		SetToggleOptionValueST(MaleEvenTonedAccentedIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleEvenTonedAccented-")
	EndEvent
EndState

State MKhajiitIdle
	Event OnSelectST()
		MaleKhajiitIdleVal = !MaleKhajiitIdleVal
		SetToggleOptionValueST(MaleKhajiitIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleKhajiit-")
	EndEvent
EndState

State MNordIdle
	Event OnSelectST()
		MaleNordIdleVal = !MaleNordIdleVal
		SetToggleOptionValueST(MaleNordIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleNord-")
	EndEvent
EndState

State MOrcIdle
	Event OnSelectST()
		MaleOrcIdleVal = !MaleOrcIdleVal
		SetToggleOptionValueST(MaleOrcIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleOrc-")
	EndEvent
EndState

State MYoungEagerIdle
	Event OnSelectST()
		MaleYoungEagerIdleVal = !MaleYoungEagerIdleVal
		SetToggleOptionValueST(MaleYoungEagerIdleVal)
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("MaleYoungEager-")
	EndEvent
EndState

; Show list of Actors the user has Added
State ActorsPreventedMenu
	Event OnMenuOpenST()
		int iSelect = 0
		While iSelect < aaa_RDOPreventedActorsList.GetSize()
			SetMenuDialogOptions(ActorsPrevented)
			SetMenuDialogStartIndex(ActorsListIndex[iSelect])
			SetMenuDialogDefaultIndex(0)
			iSelect += 1
		EndWhile
	EndEvent
	Event OnHighlightST()
		SetInfoText("$RDOPreventedActorsMenuMsg")
	EndEvent
EndState

State PreventActor
	Event OnSelectST()
		Actor crosshairActor = Game.GetCurrentCrosshairRef() as Actor
		Actor consoleActor = Game.GetCurrentConsoleRef() as Actor
		If crosshairActor
			aaa_RDOPreventedActorsList.AddForm(crosshairActor.GetLeveledActorBase())
			; Until I can figure out why crosshair/consoleActor.GetDisplayName() + "$RDOTextForTranslation" together does not display the contents of the placeholder text for translation, plain English will have to be used.
			; ShowMessage(crosshairActor.GetDisplayName() + " $RDOActorWillStopUsingDialogue", false, "$RDOMessageDisplayAccept")
			ShowMessage(crosshairActor.GetDisplayName() + " will STOP using RDO dialogue.", false, "$RDOMessageDisplayAccept")
			RDO_SetActorName(crosshairActor)
			NextActorIndex += 1
			ForcePageReset()
		ElseIf consoleActor
			aaa_RDOPreventedActorsList.AddForm(consoleActor.GetLeveledActorBase())
			; Until I can figure out why crosshair/consoleActor.GetDisplayName() + "$RDOTextForTranslation" together does not display the contents of the placeholder text for translation, plain English will have to be used.
			; ShowMessage(consoleActor.GetDisplayName() + " " + "$RDOActorWillStopUsingDialogue", false, "$RDOMessageDisplayAccept")
			ShowMessage(consoleActor.GetDisplayName() + " will STOP using RDO dialogue.", false, "$RDOMessageDisplayAccept")
			RDO_SetActorName(consoleActor)
			NextActorIndex += 1
			ForcePageReset()
		Else
			ShowMessage("$RDOUnableToPreventActorSelectNPC", false, "$RDOMessageDisplayAccept")
		EndIf
	EndEvent
EndState

State AllowActor
	Event OnSelectST()
		Actor crosshairActor = Game.GetCurrentCrosshairRef() as Actor
		Actor consoleActor = Game.GetCurrentConsoleRef() as Actor
		If crosshairActor
			aaa_RDOPreventedActorsList.RemoveAddedForm(crosshairActor.GetLeveledActorBase())
			; ShowMessage(crosshairActor.GetDisplayName() + " " + "$RDOActorWillStartUsingDialogue", false, "$RDOMessageDisplayAccept")
			ShowMessage(crosshairActor.GetDisplayName() + " will START using RDO dialogue.", false, "$RDOMessageDisplayAccept")
			RDO_RemoveActorName(crosshairActor)
			RDO_SortActorsList()
			RDO_ResetIndexPosition()
			ForcePageReset()
		ElseIf consoleActor
			aaa_RDOPreventedActorsList.RemoveAddedForm(consoleActor.GetLeveledActorBase())
			; ShowMessage(consoleActor.GetDisplayName() + " " + "$RDOActorWillStartUsingDialogue", false, "$RDOMessageDisplayAccept")
			ShowMessage(consoleActor.GetDisplayName() + " will START using RDO dialogue.", false, "$RDOMessageDisplayAccept")
			RDO_RemoveActorName(consoleActor)
			RDO_SortActorsList()
			RDO_ResetIndexPosition()
			ForcePageReset()
		Else
			ShowMessage("$RDOFailedToAllowActorSelectNPC", false, "$RDOMessageDisplayAccept")
		EndIf
	EndEvent
EndState

State RelationshipRank
	Event OnSelectST()
		; Change the disposition the actor has towards to player, cycling through ranks -2 to 4
		Actor crosshairActor = Game.GetCurrentCrosshairRef() as Actor
		Actor consoleActor = Game.GetCurrentConsoleRef() as Actor
		If crosshairActor
			SetTextOptionValueST(RDO_SetActorDisposition(crosshairActor))
		ElseIf consoleActor
			SetTextOptionValueST(RDO_SetActorDisposition(consoleActor))
		Else
			ShowMessage("$RDOFailedToChangeDisposition", false, "$RDOMessageDisplayAccept")
		EndIf
	EndEvent
	Event OnHighlightST()	;renn
		SetInfoText("RelationshipRank Desc.")
	EndEvent
EndState

State ClearAllActors
	Event OnSelectST()
		; If selected, prompt the user to make sure they actually do want to clear all actors
		bool continue = true
		string msg = "$RDOClearAllActorsPrompt"
		continue = ShowMessage(msg, true, "$RDOMessageDisplayOptionYes", "$RDOMessageDisplayOptionNo")
		If (continue)
			ShowMessage("$RDOClearingAllActorsNow", false, "$RDOMessageDisplayAccept")
			RDO_ClearAllActors()
			NextActorIndex = 0
			ShowMessage("$RDOAllActorsCleared", false, "$RDOMessageDisplayAccept")
			ForcePageReset()
		EndIf
	EndEvent
EndState

State PotentialFollower
	Event OnSelectST()
		Actor crosshairActor = Game.GetCurrentCrosshairRef() as Actor
		Actor consoleActor = Game.GetCurrentConsoleRef() as Actor
		If crosshairActor
			SetTextOptionValueST(RDO_ForcePotentialFollower(crosshairActor))
			; ShowMessage(crosshairActor.GetDisplayName() + " " + "$RDOActorIsNowPotentialFollower", false, "$RDOMessageDisplayAccept")
			ShowMessage(crosshairActor.GetDisplayName() + " is now a potential follower.", false, "$RDOMessageDisplayAccept")
			ForcePageReset()
		ElseIf consoleActor
			SetTextOptionValueST(RDO_ForcePotentialFollower(consoleActor))
			; ShowMessage(crosshairActor.GetDisplayName() + " " + "$RDOActorIsNowPotentialFollower", false, "$RDOMessageDisplayAccept")
			ShowMessage(crosshairActor.GetDisplayName() + " is now a potential follower.", false, "$RDOMessageDisplayAccept")
			ForcePageReset()
		Else
			ShowMessage("$RDOFailedToMakePotentialFollowerSelectNPC", false, "$RDOMessageDisplayAccept")
		EndIf
	EndEvent
EndState

State PotentialSpouse
	Event OnSelectST()
		Actor crosshairActor = Game.GetCurrentCrosshairRef() as Actor
		Actor consoleActor = Game.GetCurrentConsoleRef() as Actor
		If crosshairActor
			SetTextOptionValueST(RDO_ForcePotentialSpouse(crosshairActor))
			; ShowMessage(crosshairActor.GetDisplayName() + " " + "$RDOActorIsNowPotentialSpouse", false, "$RDOMessageDisplayAccept")
			ShowMessage(crosshairActor.GetDisplayName() + " is now a potential spouse.", false, "$RDOMessageDisplayAccept")
			ForcePageReset()
		ElseIf consoleActor
			SetTextOptionValueST(RDO_ForcePotentialSpouse(consoleActor))
			; ShowMessage(consoleActor.GetDisplayName() + " " + "$RDOActorIsNowPotentialSpouse", false, "$RDOMessageDisplayAccept")
			ShowMessage(consoleActor.GetDisplayName() + " is now a potential spouse.", false, "$RDOMessageDisplayAccept")
			ForcePageReset()
		Else
			ShowMessage("$RDOFailedToMakePotentialSpouseSelectNPC", false, "$RDOMessageDisplayAccept")
		EndIf
	EndEvent
EndState

State StopCombat
	Event OnSelectST()
		SetTextOptionValueST("")
		Actor crosshairActor = Game.GetCurrentCrosshairRef() as Actor
		Actor consoleActor = Game.GetCurrentConsoleRef() as Actor
		If crosshairActor
			crosshairActor.StopCombat()
			; ShowMessage(crosshairActor.GetDisplayName() + " " + "$RDOActorWillStopCombat", false, "$RDOMessageDisplayAccept")
			ShowMessage(crosshairActor.GetDisplayName() + " will stop combat.", false, "$RDOMessageDisplayAccept")
		ElseIf consoleActor
			consoleActor.StopCombat()
			; ShowMessage(consoleActor.GetDisplayName() +  " " + "$RDOActorWillStopCombat", false, "$RDOMessageDisplayAccept")
			ShowMessage(consoleActor.GetDisplayName() +  " will stop combat.", false, "$RDOMessageDisplayAccept")
		Else
			ShowMessage("$RDOUnableToStopCombatSelectNPC", false, "$RDOMessageDisplayAccept")
		EndIf
	EndEvent
EndState

State StopCombatAlarm
	Event OnSelectST()
		SetTextOptionValueST("")
		Actor crosshairActor = Game.GetCurrentCrosshairRef() as Actor
		Actor consoleActor = Game.GetCurrentConsoleRef() as Actor
		If crosshairActor
			crosshairActor.StopCombatAlarm()
			; ShowMessage(crosshairActor.GetDisplayName() + " " + "$RDOActorWillStopCombatAlarm", false, "$RDOMessageDisplayAccept")
			ShowMessage(crosshairActor.GetDisplayName() + " and enemies will stop combat.", false, "$RDOMessageDisplayAccept")
		ElseIf consoleActor
			consoleActor.StopCombatAlarm()
			; ShowMessage(consoleActor.GetDisplayName() + " " + "$RDOActorWillStopCombatAlarm", false, "$RDOMessageDisplayAccept")
			ShowMessage(consoleActor.GetDisplayName() + " and enemies will stop combat.", false, "$RDOMessageDisplayAccept")
		Else
			ShowMessage("$RDOUnableToStopCombatSelectNPC", false, "$RDOMessageDisplayAccept")
		EndIf
	EndEvent
EndState

State StopCombatAlarmPlayer
	Event OnSelectST()
		SetTextOptionValueST("")
		PlayerRef.StopCombatAlarm()
		ShowMessage("$RDOPlayerWillStopCombatAlarm", false, "$RDOMessageDisplayAccept")
	EndEvent
EndState

State AggressionLevel
	Event OnSelectST()
		Actor crosshairActor = Game.GetCurrentCrosshairRef() as Actor
		Actor consoleActor = Game.GetCurrentConsoleRef() as Actor
		If crosshairActor
			SetTextOptionValueST(RDO_SetActorAggression(crosshairActor))
		ElseIf consoleActor
			SetTextOptionValueST(RDO_SetActorAggression(consoleActor))
		Else
			ShowMessage("$RDOUnableToChangeActorAggression", false, "$RDOMessageDisplayAccept")
		EndIf
	EndEvent
	
	Event OnHighlightST()
		SetInfoText("$RDOAggressionInfoMsg")
	EndEvent
EndState

State ConfidenceLevel
	Event OnSelectST()
		Actor crosshairActor = Game.GetCurrentCrosshairRef() as Actor
		Actor consoleActor = Game.GetCurrentConsoleRef() as Actor
		If crosshairActor
			SetTextOptionValueST(RDO_SetActorConfidence(crosshairActor))
		ElseIf consoleActor
			SetTextOptionValueST(RDO_SetActorConfidence(consoleActor))
		Else
			ShowMessage("$RDOUnableToChangeActorConfidence", false, "$RDOMessageDisplayAccept")
		EndIf
	EndEvent
	
	Event OnHighlightST()
		SetInfoText("$RDOConfidenceInfoMsg")
	EndEvent
EndState